{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 300,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/biom-format:2.1.6--py36_0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "biom-convert.sh"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3746",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-convert.cwl/biom"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as HDF5-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-hdf5"
                    },
                    "id": "#biom-convert.cwl/hdf5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The observation metadata to include from the input BIOM table file when\ncreating a tsv table file. By default no observation metadata will be\nincluded.\n",
                    "inputBinding": {
                        "prefix": "--header-key"
                    },
                    "id": "#biom-convert.cwl/header_key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as JSON-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-json"
                    },
                    "id": "#biom-convert.cwl/json"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--table-type",
                        "separate": true,
                        "valueFrom": "$(inputs.table_type)"
                    },
                    "id": "#biom-convert.cwl/table_type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as TSV-formatted (classic) table.",
                    "inputBinding": {
                        "prefix": "--to-tsv"
                    },
                    "id": "#biom-convert.cwl/tsv"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "${ var ext = \"\";\n   if (inputs.json) { ext = \"_json.biom\"; }\n   if (inputs.hdf5) { ext = \"_hdf5.biom\"; }\n   if (inputs.tsv) { ext = \"_tsv.biom\"; }\n   var pre = inputs.biom.nameroot.split('.');\n   pre.pop()\n   return pre.join('.') + ext; }\n",
                    "prefix": "--output-fp"
                },
                {
                    "valueFrom": "--collapsed-observations"
                }
            ],
            "id": "#biom-convert.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${ var ext = \"\";\nif (inputs.json) { ext = \"_json.biom\"; }\nif (inputs.hdf5) { ext = \"_hdf5.biom\"; }\nif (inputs.tsv) { ext = \"_tsv.biom\"; }\nvar pre = inputs.biom.nameroot.split('.');\npre.pop()\nreturn pre.join('.') + ext; }\n"
                    },
                    "id": "#biom-convert.cwl/result"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmsearch-deoverlap.pl"
            ],
            "inputs": [
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/clan_information",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--clanin"
                    },
                    "label": "clan information on the models provided",
                    "doc": "Not all models provided need to be a member of a clan"
                },
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/cmsearch_matches",
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/deoverlapped_matches",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "label": "target hits table, format 2",
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*.deoverlapped"
                    }
                }
            ],
            "doc": "https://github.com/nawrockie/cmsearch_tblout_deoverlap/blob/master/00README.txt",
            "label": "Remove lower scoring overlaps from cmsearch --tblout files.",
            "requirements": [
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envValue": "C",
                            "envName": "LC_ALL"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 200,
                    "coresMin": 2
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.cmsearch_matches)"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://github.com/nawrockie/cmsearch_tblout_deoverlap"
                            ],
                            "version": [
                                "0.02"
                            ],
                            "package": "cmsearch_tblout_deoverlap"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biocrusoe/cmsearch-deoverlap"
                }
            ],
            "id": "#cmsearch-deoverlap-v0.02.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmsearch"
            ],
            "inputs": [
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/covariance_model_database",
                    "type": [
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/cpu",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--cpu"
                    },
                    "label": "Number of parallel CPU workers to use for multithreads"
                },
                {
                    "default": false,
                    "id": "#infernal-cmsearch-v1.1.2.cwl/cut_ga",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--cut_ga"
                    },
                    "label": "use CM's GA gathering cutoffs as reporting thresholds"
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/omit_alignment_section",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--noali"
                    },
                    "label": "Omit the alignment section from the main output.",
                    "doc": "This can greatly reduce the output volume."
                },
                {
                    "default": false,
                    "id": "#infernal-cmsearch-v1.1.2.cwl/only_hmm",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--hmmonly"
                    },
                    "label": "Only use the filter profile HMM for searches, do not use the CM",
                    "doc": "Only filter stages F1 through F3 will be executed, using strict P-value\nthresholds (0.02 for F1, 0.001 for F2 and 0.00001 for F3). Additionally\na bias composition filter is used after the F1 stage (with P=0.02\nsurvival threshold). Any hit that survives all stages and has an HMM\nE-value or bit score above the reporting threshold will be output.\n"
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/query_sequences",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 2
                    }
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/search_space_size",
                    "type": "int",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-Z"
                    },
                    "label": "search space size in *Mb* to <x> for E-value calculations"
                }
            ],
            "outputs": [
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/matches",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "label": "target hits table, format 2",
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "${\n  var name = \"\";\n  if (typeof inputs.covariance_model_database == \"string\") {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.split(\"/\").slice(-1)[0] +\n      \".cmsearch_matches.tbl\";\n  } else {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.nameroot +\n      \".cmsearch_matches.tbl\";\n  }\n  return name;\n}\n"
                    }
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/programOutput",
                    "label": "direct output to file, not stdout",
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "${\n  var name = \"\";\n  if (typeof inputs.covariance_model_database == \"string\") {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.split(\"/\").slice(-1)[0] +\n      \".cmsearch.out\";\n  } else {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.nameroot +\n      \".cmsearch.out\";\n  }\n  return name;\n}\n"
                    }
                }
            ],
            "doc": "Infernal (\"INFERence of RNA ALignment\") is for searching DNA sequence databases for RNA structure and sequence similarities. It is an implementation of a special case of profile stochastic context-free grammars called covariance models (CMs). A CM is like a sequence profile, but it scores a combination of sequence consensus and RNA secondary structure consensus, so in many cases, it is more capable of identifying RNA homologs that conserve their secondary structure more than their primary sequence.\nPlease visit http://eddylab.org/infernal/ for full documentation.\nVersion 1.1.2 can be downloaded from http://eddylab.org/infernal/infernal-1.1.2.tar.gz\n",
            "label": "Search sequence(s) against a covariance model database",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--tblout",
                    "valueFrom": "${\n  var name = \"\";\n  if (typeof inputs.covariance_model_database == \"string\") {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.split(\"/\").slice(-1)[0] +\n      \".cmsearch_matches.tbl\";\n  } else {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.nameroot +\n      \".cmsearch_matches.tbl\";\n  }\n  return name;\n}\n"
                },
                {
                    "position": 0,
                    "prefix": "-o",
                    "valueFrom": "${\n  var name = \"\";\n  if (typeof inputs.covariance_model_database == \"string\") {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.split(\"/\").slice(-1)[0] +\n      \".cmsearch.out\";\n  } else {\n    name =\n      inputs.query_sequences.basename +\n      \".\" +\n      inputs.covariance_model_database.nameroot +\n      \".cmsearch.out\";\n  }\n  return name;\n}\n"
                },
                {
                    "valueFrom": "> /dev/null",
                    "shellQuote": false,
                    "position": 10
                },
                {
                    "valueFrom": "2> /dev/null",
                    "shellQuote": false,
                    "position": 11
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011809"
                            ],
                            "version": [
                                "1.1.2"
                            ],
                            "package": "infernal"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/infernal:1.1.2--h470a237_1"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "coresMin": 8
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "id": "#infernal-cmsearch-v1.1.2.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew, Ekaterina Sakharova"
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/hmmer:3.2.1--hf484d3e_1",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "esl-index.sh"
            ],
            "requirements": [
                {
                    "listing": [
                        "$(inputs.sequences)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    },
                    "label": "Input fasta file.",
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".ssi"
                        }
                    ],
                    "outputBinding": {
                        "glob": "folder/$(inputs.sequences.basename)"
                    },
                    "label": "The index file",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/hmmer:3.2.1--hf484d3e_1",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-Cf",
                        "position": 1
                    },
                    "secondaryFiles": [
                        {
                            "pattern": ".ssi"
                        }
                    ],
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "$(inputs.indexed_sequences.basename)_$(inputs.names_contain_subseq_coords.basename).fasta",
            "outputs": [
                {
                    "type": "File",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "$(inputs.indexed_sequences.basename)_$(inputs.names_contain_subseq_coords.basename).fasta"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 2,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "output from infernal cmsearch",
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#extract-coords_awk.cwl/infernal_matches"
                },
                {
                    "label": "output file name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-n",
                        "valueFrom": "$(self? self : inputs.infernal_matches.basename)\n"
                    },
                    "default": "",
                    "id": "#extract-coords_awk.cwl/name"
                }
            ],
            "baseCommand": "awk_tool",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*matched_seqs_with_coords*"
                    },
                    "id": "#extract-coords_awk.cwl/matched_seqs_with_coords"
                }
            ],
            "doc": "The awk script takes the output of Infernal's cmsearch so-called fmt=1 mode\nand makes it suitable for use by esl-sfetch, a sequence selector\n\nReading the user's guide for Infernal, Version 1.1.2; July 2016\nhttp://eddylab.org/infernal/Userguide.pdf#page=60 we see that\nthe relevant fields in the cmsearch output are:\n(column number: explanation)\n1: The name of the target sequence or profile\n3: The name of the query sequence or profile\n8: The start of the alignment of this hit with respect to the\n    sequence, numbered 1..L for a sequence of L residues.\n9: The end of the alignment of this hit with respect to the sequence,\n    numbered 1..L for a sequence of L residues\n\nLikewise the format esl-sfetch wants is: <newname> <from> <to> <source seqname>\n\nPutting it all together we see that the newname (which esl-sfetch with\noutput using) is a concatenation of the original name, the sequence\nnumber, and the coordinates.\n",
            "id": "#extract-coords_awk.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "fasta file (from esl) with all subunits",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#get_subunits_coords.cwl/input"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#get_subunits_coords.cwl/pattern_LSU"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#get_subunits_coords.cwl/pattern_SSU"
                }
            ],
            "baseCommand": "get_subunits_coords.py",
            "stdout": "stdout.txt",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*LSU*"
                    },
                    "id": "#get_subunits_coords.cwl/LSU_seqs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*SSU*"
                    },
                    "id": "#get_subunits_coords.cwl/SSU_seqs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "RNA-counts"
                    },
                    "id": "#get_subunits_coords.cwl/counts"
                },
                {
                    "type": "File",
                    "id": "#get_subunits_coords.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#get_subunits_coords.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "fasta file (from esl) with all subunits",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#get_subunits.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-e"
                    },
                    "id": "#get_subunits.cwl/pattern_5.8S"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#get_subunits.cwl/pattern_5S"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#get_subunits.cwl/pattern_LSU"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#get_subunits.cwl/pattern_SSU"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#get_subunits.cwl/prefix"
                }
            ],
            "baseCommand": "get_subunits.py",
            "stdout": "stdout.txt",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "sequence-categorisation/*LSU.fasta*"
                    },
                    "id": "#get_subunits.cwl/LSU_seqs"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "sequence-categorisation/*SSU.fasta*"
                    },
                    "id": "#get_subunits.cwl/SSU_seqs"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "sequence-categorisation/*.fa"
                    },
                    "id": "#get_subunits.cwl/fastas"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "sequence-categorisation"
                    },
                    "id": "#get_subunits.cwl/sequence-categorisation"
                },
                {
                    "type": "File",
                    "id": "#get_subunits.cwl/stdout",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    }
                }
            ],
            "id": "#get_subunits.cwl",
            "http://schema.org/author": "Ekaterina Sakharova, Varsha Kale",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "label": "visualize using krona",
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Tab-delimited text file",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#krona.cwl/otu_counts"
                }
            ],
            "baseCommand": "ktImportText",
            "arguments": [
                {
                    "valueFrom": "krona.html",
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/html",
                    "outputBinding": {
                        "glob": "*.html"
                    },
                    "id": "#krona.cwl/otu_visualization"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "kronav2.7.1:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "id": "#krona.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "MAPseq v 1.2.3",
            "doc": "sequence read classification tools designed to assign taxonomy and OTU\nclassifications to ribosomal RNA sequences.\nhttps://github.com/jfmrod/MAPseq\n",
            "requirements": [
                {
                    "ramMin": 25000,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster"
                        }
                    ],
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/database"
                },
                {
                    "type": "File",
                    "id": "#mapseq.cwl/prefix"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/sequences"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mapseq.cwl/taxonomy"
                }
            ],
            "baseCommand": "mapseq",
            "arguments": [
                "-nthreads",
                "8",
                "-tophits",
                "80",
                "-topotus",
                "40",
                "-outfmt",
                "simple"
            ],
            "stdout": "$(inputs.prefix.nameroot)_$(inputs.database.basename).mseq",
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "id": "#mapseq.cwl/classifications",
                    "outputBinding": {
                        "glob": "$(inputs.prefix.nameroot)_$(inputs.database.basename).mseq"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mapseq:latest"
                }
            ],
            "id": "#mapseq.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mapseq2biom:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "ramMin": 200,
                    "tmpdirMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "label to add to the top of the outfile OTU table",
                    "inputBinding": {
                        "prefix": "--label"
                    },
                    "id": "#mapseq2biom.cwl/label"
                },
                {
                    "type": "string",
                    "doc": "the OTU table produced for the taxonomies found in the reference\ndatabases that was used with MAPseq\n",
                    "inputBinding": {
                        "prefix": "--otuTable"
                    },
                    "id": "#mapseq2biom.cwl/otu_table"
                },
                {
                    "type": "File",
                    "label": "the output from the MAPseq that assigns a taxonomy to a sequence",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "inputBinding": {
                        "prefix": "--query"
                    },
                    "id": "#mapseq2biom.cwl/query"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "output NCBI taxids for all databases bar UNITE",
                    "inputBinding": {
                        "prefix": "--taxid"
                    },
                    "id": "#mapseq2biom.cwl/taxid_flag"
                }
            ],
            "baseCommand": [
                "mapseq2biom.pl"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.query.basename).tsv",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "$(inputs.query.basename).txt",
                    "prefix": "--krona"
                },
                {
                    "valueFrom": "$(inputs.query.basename).notaxid.tsv",
                    "prefix": "--notaxidfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).tsv"
                    },
                    "id": "#mapseq2biom.cwl/otu_tsv"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).notaxid.tsv"
                    },
                    "id": "#mapseq2biom.cwl/otu_tsv_notaxid"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).txt"
                    },
                    "id": "#mapseq2biom.cwl/otu_txt"
                }
            ],
            "id": "#mapseq2biom.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 2,
                    "ramMin": 500,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/seqprep:1.1--1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "label": "first read input fastq",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#seqprep.cwl/forward_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#seqprep.cwl/namefile"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "label": "second read input fastq",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#seqprep.cwl/reverse_reads"
                }
            ],
            "baseCommand": "SeqPrep",
            "arguments": [
                "-1",
                "forward_unmerged.fastq.gz",
                "-2",
                "reverse_unmerged.fastq.gz",
                {
                    "valueFrom": "${ return inputs.namefile.nameroot.split('_')[0] + '_MERGED.fastq.gz' }\n",
                    "prefix": "-s"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.forward_reads.format)",
                    "outputBinding": {
                        "glob": "forward_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/forward_unmerged_reads"
                },
                {
                    "type": "File",
                    "format": "$(inputs.forward_reads.format)",
                    "outputBinding": {
                        "glob": "*_MERGED*"
                    },
                    "id": "#seqprep.cwl/merged_reads"
                },
                {
                    "type": "File",
                    "format": "$(inputs.forward_reads.format)",
                    "outputBinding": {
                        "glob": "reverse_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/reverse_unmerged_reads"
                }
            ],
            "doc": "SeqPrep is a program to merge paired end Illumina reads that are overlapping into a single longer read. It may also just be used for its adapter trimming feature without doing any paired end overlap. When an adapter sequence is present, that means that the two reads must overlap (in most cases) so they are forcefully merged. When reads do not have adapter sequence they must be treated with care when doing the merging, so a much more specific approach is taken. The default parameters were chosen with specificity in mind, so that they could be ran on libraries where very few reads are expected to overlap. It is always safest though to save the overlapping procedure for libraries where you have some prior knowledge that a significant portion of the reads will have some overlap.\n",
            "label": "Tool for stripping adaptors and/or merging paired reads with overlap into single reads.",
            "id": "#seqprep.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/trimmomatic:0.36--6"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMax": 16384,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "trimmomatic.sh"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "AVGQUAL:",
                        "separate": false
                    },
                    "label": "minimum average quality required",
                    "doc": "Drop the read if the average quality is below the specified level\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/avgqual"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "label": "read cropping",
                    "doc": "Removes bases regardless of quality from the end of the read, so that the read has maximally the specified length after this step has been performed. Steps performed after CROP might of course further shorten the read. The value is the number of bases to keep, from the start of the read.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/crop"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": "read -end mode format",
                    "doc": "Single End (SE) or Paired End (PE) mode\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/end_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "label": "read head trimming",
                    "doc": "Removes the specified number of bases, regardless of quality, from the beginning of the read. The numbser specified is the number of bases to keep, from the start of the read.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/headcrop"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if ( self ) {\n     return \"ILLUMINACLIP:\" + inputs.illuminaClip.adapters.path + \":\"\n       + self.seedMismatches + \":\" + self.palindromeClipThreshold + \":\"\n       + self.simpleClipThreshold + \":\" + self.minAdapterLength + \":\"\n       + self.keepBothReads;\n   } else {\n     return self;\n   }\n }\n",
                        "position": 11
                    },
                    "label": "sequencing adaptater removing",
                    "doc": "Cut adapter and other illumina-specific sequences from the read.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/illuminaClip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "label": "read tail trimming",
                    "doc": "Remove low quality bases from the beginning. As long as a base has a value below this threshold the base is removed and the next base will be investigated.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/leading"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "${ if ( self ) {\n     return \"MAXINFO:\" + self.targetLength + \":\" + self.strictness;\n   } else {\n     return self;\n   }\n }\n"
                    },
                    "label": "maxinfo: read score quality filtering",
                    "doc": "Performs an adaptive quality trim, balancing the benefits of retaining longer reads against the costs of retaining bases with errors. <targetLength>: This specifies the read length which is likely to allow the location of the read within the target sequence to be determined. <strictness>: This value, which should be set between 0 and 1, specifies the balance between preserving as much read length as possible vs. removal of incorrect bases. A low value of this parameter (<0.2) favours longer reads, while a high value (>0.8) favours read correctness.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/maxinfo"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 100,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "label": "minimum length read filter",
                    "doc": "This module removes reads that fall below the specified minimal length. If required, it should normally be after all other processing steps. Reads removed by this step will be counted and included in the \"dropped reads\" count presented in the trimmomatic summary.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/minlen"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 4
                    },
                    "label": "quality score format",
                    "doc": "Either PHRED \"33\" or \"64\" specifies the base quality encoding. Default: 64\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/phred"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "label": "FASTQ read file 1",
                    "doc": "FASTQ file of reads (R1 reads in Paired End mode)\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/reads1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "label": "FASTQ read file 2",
                    "doc": "FASTQ file of R2 reads in Paired End mode\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/reads2"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "SLIDINGWINDOW:",
                        "separate": false
                    },
                    "label": "read filtering sliding window",
                    "doc": "Perform a sliding window trimming, cutting once the average quality within the window falls below a threshold. By considering multiple bases, a single poor quality base will not cause the removal of high quality data later in the read. <windowSize> specifies the number of bases to average across <requiredQuality> specifies the average quality required\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/slidingwindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "label": "quality score conversion to phred33",
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/tophred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "label": "quality score conversion to phred64",
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/tophred64"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "label": "read tail quality filtering",
                    "doc": "Remove low quality bases from the end. As long as a base has a value below this threshold the base is removed and the next base (which as trimmomatic is starting from the 3' prime end would be base preceding the just removed base) will be investigated. This approach can be used removing the special Illumina \"low quality segment\" regions (which are marked with quality score of 2), but we recommend Sliding Window or MaxInfo instead\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/trailing"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trim.log"
                    },
                    "label": "Log file",
                    "doc": "log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/log_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).trimmed"
                    },
                    "id": "#Trimmomatic-v0.36-SE.cwl/reads1_trimmed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.basename).trimmed.unpaired.fastq"
                    },
                    "id": "#Trimmomatic-v0.36-SE.cwl/reads1_trimmed_unpaired"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "trim.log",
                    "prefix": "-trimlog",
                    "position": 4
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 4,
                    "prefix": "-threads"
                },
                {
                    "valueFrom": "$(inputs.reads1.nameroot).trimmed",
                    "position": 7
                }
            ],
            "doc": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop Illumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem depending on the library preparation and downstream application. There are two major modes of the program: Paired end mode and Single end mode. The paired end mode will maintain correspondence of read pairs and also use the additional information contained in paired reads to better find adapter or PCR primer fragments introduced by the library preparation process. Trimmomatic works with FASTQ files (using phred + 33 or phred + 64 quality scores, depending on the Illumina pipeline used).\n",
            "label": "Trimmomatic - A flexible read trimming tool for Illumina NGS data",
            "id": "#Trimmomatic-v0.36-SE.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "split FASTA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.seqs)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "mgnify/pipeline-v5.dna_chunking:latest",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#fasta_chunker.cwl/chunk_size"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#fasta_chunker.cwl/number_of_output_files"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#fasta_chunker.cwl/same_number_of_residues"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#fasta_chunker.cwl/seqs"
                }
            ],
            "baseCommand": [
                "esl-ssplit.sh"
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.seqs.basename).*"
                    },
                    "id": "#fasta_chunker.cwl/chunks"
                }
            ],
            "id": "#fasta_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "split FAA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 8000,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#protein_chunker.cwl/chunk_size"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#protein_chunker.cwl/file_format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#protein_chunker.cwl/seqs"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "> /dev/null",
                    "shellQuote": false,
                    "position": 10
                },
                {
                    "valueFrom": "2> /dev/null",
                    "shellQuote": false,
                    "position": 11
                }
            ],
            "baseCommand": [
                "split_to_chunks.py"
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_*"
                    },
                    "id": "#protein_chunker.cwl/chunks"
                }
            ],
            "id": "#protein_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "mask SSU and LSU coorindates with bedtools for ITS",
            "doc": "https://bedtools.readthedocs.io/en/latest/content/tools/maskfasta.html",
            "requirements": [
                {
                    "coresMin": 4,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/bedtools:2.28.0--hdf88d34_0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-bed"
                    },
                    "label": "maskfile",
                    "id": "#bedtools.cwl/maskfile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-fi"
                    },
                    "label": "Input fasta file.",
                    "id": "#bedtools.cwl/sequences"
                }
            ],
            "baseCommand": [
                "bedtools",
                "maskfasta"
            ],
            "arguments": [
                {
                    "valueFrom": "ITS_masked.fasta",
                    "prefix": "-fo"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "ITS_masked.fasta"
                    },
                    "id": "#bedtools.cwl/masked_sequences"
                }
            ],
            "id": "#bedtools.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "reformat coords file for masking with bedtools",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "SSU and LSU coordinates combined",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#format-bedfile.cwl/all_coordinates"
                }
            ],
            "baseCommand": [
                "format_bedfile"
            ],
            "stdout": "ITS-maskfile",
            "outputs": [
                {
                    "type": "File",
                    "id": "#format-bedfile.cwl/maskfile",
                    "outputBinding": {
                        "glob": "ITS-maskfile"
                    }
                }
            ],
            "id": "#format-bedfile.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "identify amplicon data type and suppress the the others",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 8000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--its-dir"
                    },
                    "id": "#suppress_tax.cwl/its_dir"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--its-file"
                    },
                    "id": "#suppress_tax.cwl/its_file"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--lsu-dir"
                    },
                    "id": "#suppress_tax.cwl/lsu_dir"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--lsu-file"
                    },
                    "id": "#suppress_tax.cwl/lsu_file"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--ssu-dir"
                    },
                    "id": "#suppress_tax.cwl/ssu_dir"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--ssu-file"
                    },
                    "id": "#suppress_tax.cwl/ssu_file"
                }
            ],
            "baseCommand": [
                "its-length-new.py"
            ],
            "stdout": "ITS_LENGTH",
            "outputs": [
                {
                    "type": "File",
                    "id": "#suppress_tax.cwl/its_length",
                    "outputBinding": {
                        "glob": "ITS_LENGTH"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*.fasta.gz"
                    },
                    "id": "#suppress_tax.cwl/out_fastas_tax"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "suppressed"
                    },
                    "id": "#suppress_tax.cwl/out_suppress"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "taxonomy-summary"
                    },
                    "id": "#suppress_tax.cwl/out_tax"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#suppress_tax.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Quality control filtering step using the BioPython package.",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "run_quality_filtering.py"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#qc-filtering.cwl/input_file_format"
                },
                {
                    "type": "int",
                    "default": 100,
                    "label": "Minimum read or contig length",
                    "doc": "Specify the minimum read or contig length for sequences to pass QC filtering.\n",
                    "id": "#qc-filtering.cwl/min_length"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "Trimmed sequence file",
                    "doc": "Trimmed and FASTQ to FASTA converted sequences file.\n",
                    "id": "#qc-filtering.cwl/seq_file"
                },
                {
                    "type": "string",
                    "default": "stats_summary",
                    "label": "Post QC stats output file name",
                    "doc": "Give a name for the file which will hold the stats after QC.\n",
                    "id": "#qc-filtering.cwl/stats_file_name"
                },
                {
                    "type": "int",
                    "label": "Number of submitted sequences",
                    "doc": "Number of originally submitted sequences as in the user submitted FASTQ file - single end FASTQ or pair end merged FASTQ file.\n",
                    "id": "#qc-filtering.cwl/submitted_seq_count"
                }
            ],
            "outputs": [
                {
                    "label": "Filtered output file",
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.seq_file.nameroot).fasta"
                    },
                    "id": "#qc-filtering.cwl/filtered_file"
                },
                {
                    "label": "Stats summary output file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.stats_file_name)"
                    },
                    "id": "#qc-filtering.cwl/stats_summary_file"
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(inputs.seq_file.nameroot).fasta"
                },
                {
                    "position": 3,
                    "valueFrom": "$(inputs.stats_file_name)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.submitted_seq_count)"
                },
                {
                    "position": 5,
                    "prefix": "--min_length",
                    "valueFrom": "$(inputs.min_length)"
                },
                {
                    "position": 6,
                    "prefix": "--extension",
                    "valueFrom": "$(inputs.input_file_format)"
                }
            ],
            "id": "#qc-filtering.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Post QC-ed input analysis of sequence file",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "qc-stats:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$({class: 'Directory', listing: []})",
                            "entryname": "$(inputs.out_dir_name)",
                            "writable": true
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 900,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "MGRAST_base.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#qc-stats.cwl/QCed_reads"
                },
                {
                    "label": "Prefix for the files associated with GC distribution",
                    "type": "string",
                    "default": "GC-distribution.out",
                    "id": "#qc-stats.cwl/gc_sum"
                },
                {
                    "label": "Prefix for the files assocaited with sequence length distribution",
                    "type": "string",
                    "default": "seq-length.out",
                    "id": "#qc-stats.cwl/length_sum"
                },
                {
                    "label": "Maximum number of sequences to sub-sample",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2000000,
                    "id": "#qc-stats.cwl/max_seq"
                },
                {
                    "label": "Prefix for the files associated with nucleotide distribution",
                    "type": "string",
                    "default": "nucleotide-distribution.out",
                    "id": "#qc-stats.cwl/nucleotide_distribution"
                },
                {
                    "label": "Specifies output subdirectory",
                    "type": "string",
                    "default": "qc-statistics",
                    "id": "#qc-stats.cwl/out_dir_name"
                },
                {
                    "label": "Specifies the number of sequences in the input read file (FASTA formatted)",
                    "type": "int",
                    "id": "#qc-stats.cwl/sequence_count"
                },
                {
                    "label": "File names for summary of sequences, e.g. number, min/max length etc.",
                    "type": "string",
                    "default": "summary.out",
                    "id": "#qc-stats.cwl/summary"
                }
            ],
            "outputs": [
                {
                    "label": "Contains all stats output files",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)"
                    },
                    "id": "#qc-stats.cwl/output_dir"
                },
                {
                    "label": "Contains the summary statistics for the input sequence file",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)/$(inputs.summary)"
                    },
                    "id": "#qc-stats.cwl/summary_out"
                }
            ],
            "arguments": [
                {
                    "position": 1,
                    "prefix": "-o",
                    "valueFrom": "$(inputs.out_dir_name)/$(inputs.summary)"
                },
                {
                    "position": 2,
                    "prefix": "-d",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.nucleotide_distribution, suffix);\n}\n"
                },
                {
                    "position": 3,
                    "prefix": "-g",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.gc_sum, suffix);\n}\n"
                },
                {
                    "position": 4,
                    "prefix": "-l",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.length_sum, suffix);\n}\n"
                },
                {
                    "position": 5,
                    "valueFrom": "${ if (inputs.sequence_count > inputs.max_seq) { return '-m '.concat(inputs.max_seq)} else { return ''} }"
                }
            ],
            "id": "#qc-stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Replaces problematic characters from FASTA headers with dashes",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#clean_fasta_headers.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": [
                "tr",
                "\" /|<_;#\"",
                "-------"
            ],
            "stdout": "$(inputs.sequences.nameroot).unfiltered_fasta",
            "outputs": [
                {
                    "type": "File",
                    "id": "#clean_fasta_headers.cwl/sequences_with_cleaned_headers",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.nameroot).unfiltered_fasta"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#clean_fasta_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Redirecting Multiple Files Contain in a Single File",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "baseCommand": [
                "cat"
            ],
            "inputs": [
                {
                    "type": [
                        {
                            "type": "array",
                            "items": [
                                "File",
                                "string"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concatenate.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#concatenate.cwl/outputFileName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#concatenate.cwl/postfix"
                }
            ],
            "stdout": "$(inputs.outputFileName)$(inputs.postfix)",
            "outputs": [
                {
                    "id": "#concatenate.cwl/result",
                    "type": "File",
                    "format": "${if ((typeof(inputs.files[0]) == 'string') || (inputs.files.length == 0)) return 'undefined'; else { if (\"format\" in inputs.files[0]) return inputs.files[0].format; else return 'undefined'} }",
                    "outputBinding": {
                        "glob": "$(inputs.outputFileName)$(inputs.postfix)"
                    }
                }
            ],
            "doc": "The cat (short for concatenate) command is one of the most frequently used command in Linux/Unix like operating systems. cat command allows us to create single or multiple files, view contain of file, concatenate files and redirect output in terminal or files.\n",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 200,
                    "coresMax": 1
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "id": "#concatenate.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "grep",
                "-c",
                "^>"
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#count_fasta.cwl/number"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count_fasta.cwl/sequences"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "|",
                    "position": 2,
                    "shellQuote": false
                },
                {
                    "valueFrom": "cat",
                    "shellQuote": false,
                    "position": 3
                }
            ],
            "stdout": "grepcount",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "grepcount",
                        "loadContents": true,
                        "outputEval": "${\n  var grep_count = parseInt(self[0].contents) || 0;\n  if (grep_count === 0) {\n    return 0;\n  } else {\n    return parseInt(grep_count / inputs.number);\n  }\n}\n"
                    },
                    "id": "#count_fasta.cwl/count"
                }
            ],
            "id": "#count_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 2,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "count_lines.py"
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "id": "#count_lines.cwl/number"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#count_lines.cwl/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "data.txt",
                        "loadContents": true,
                        "outputEval": "$(parseInt(self[0].contents))"
                    },
                    "id": "#count_lines.cwl/count"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#count_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#count_number_lines.cwl/input_file"
                }
            ],
            "baseCommand": [
                "bash"
            ],
            "arguments": [
                {
                    "valueFrom": "expr \\$(cat $(inputs.input_file.path) | wc -l)\n",
                    "prefix": "-c"
                }
            ],
            "stdout": "count",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "count",
                        "outputEval": "$(Number(self[0].contents))",
                        "loadContents": true
                    },
                    "id": "#count_number_lines.cwl/number"
                }
            ],
            "id": "#count_number_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "doc": "Modified from https://github.com/nigyta/bact_genome/blob/master/cwl/tool/fastp/fastp.cwl\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 8,
                    "ramMin": 3800,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "fastp"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--correction"
                    },
                    "id": "#fastp.cwl/base_correction"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--disable_trim_poly_g"
                    },
                    "id": "#fastp.cwl/disable_trim_poly_g"
                },
                {
                    "type": "File",
                    "format": [
                        "http://edamontology.org/format_1930",
                        "http://edamontology.org/format_1929"
                    ],
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#fastp.cwl/fastq1"
                },
                {
                    "format": [
                        "http://edamontology.org/format_1930",
                        "http://edamontology.org/format_1929"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-I"
                    },
                    "id": "#fastp.cwl/fastq2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--trim_poly_g"
                    },
                    "id": "#fastp.cwl/force_polyg_tail_trimming"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 50,
                    "inputBinding": {
                        "prefix": "--length_required"
                    },
                    "id": "#fastp.cwl/min_length_required"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "prefix": "--qualified_quality_phred"
                    },
                    "id": "#fastp.cwl/qualified_phred_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--thread"
                    },
                    "id": "#fastp.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "prefix": "--unqualified_percent_limit"
                    },
                    "id": "#fastp.cwl/unqualified_phred_quality"
                }
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(inputs.fastq1.nameroot).fastp.fastq"
                },
                "${\n  if (inputs.fastq2){\n    return '-O';\n  } else {\n    return '';\n  }\n}\n",
                "${\n  if (inputs.fastq2){\n    return inputs.fastq2.nameroot + \".fastp.fastq\";\n  } else {\n    return '';\n  }\n}\n"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "fastp.html"
                    },
                    "id": "#fastp.cwl/html_report"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "fastp.json"
                    },
                    "id": "#fastp.cwl/json_report"
                },
                {
                    "type": "File",
                    "format": "$(inputs.fastq1.format)",
                    "outputBinding": {
                        "glob": "$(inputs.fastq1.nameroot).fastp.fastq"
                    },
                    "id": "#fastp.cwl/out_fastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "$(inputs.fastq2.format)",
                    "outputBinding": {
                        "glob": "$(inputs.fastq2.nameroot).fastp.fastq"
                    },
                    "id": "#fastp.cwl/out_fastq2"
                }
            ],
            "id": "#fastp.cwl",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 300,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "biopython/biopython:latest",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#fastq_to_fasta.cwl/fastq"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.fastq.nameroot).unclean",
                    "prefix": "-o"
                }
            ],
            "baseCommand": [
                "fastq_to_fasta.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "*.unclean"
                    },
                    "id": "#fastq_to_fasta.cwl/fasta"
                }
            ],
            "id": "#fastq_to_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "id": "#generate_checksum.cwl/input_file"
                }
            ],
            "baseCommand": [
                "generate_checksum.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*sha1"
                    },
                    "id": "#generate_checksum.cwl/hashsum"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#generate_checksum.cwl",
            "https://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "https://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "unzip files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 2000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": null,
                            "package": "gunzip"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "is this an assembly file?",
                    "id": "#multiple-gunzip.cwl/assembly"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 2
                    },
                    "label": "for seqprep result: unmerged forward seqprep output or single end reads",
                    "id": "#multiple-gunzip.cwl/forward_unmerged_reads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "are these raw reads or amplicon reads?",
                    "id": "#multiple-gunzip.cwl/reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": " unmerged reverse seqprep output",
                    "id": "#multiple-gunzip.cwl/reverse_unmerged_reads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "merged seq prep output",
                    "id": "#multiple-gunzip.cwl/target_reads"
                }
            ],
            "baseCommand": [
                "gunzip",
                "-c"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.target_reads.format)",
                    "id": "#multiple-gunzip.cwl/unzipped_file",
                    "outputBinding": {
                        "glob": "${ var ext = \"\"; if (inputs.assembly) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTA.unfiltered'; } if (inputs.reads) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTQ.fastq'; } return ext; }"
                    }
                }
            ],
            "stdout": "${ var ext = \"\"; if (inputs.assembly) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTA.unfiltered'; } if (inputs.reads) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTQ.fastq'; } return ext; }",
            "id": "#multiple-gunzip.cwl",
            "https://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "https://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 16,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#gzip.cwl/uncompressed_file"
                }
            ],
            "baseCommand": [
                "pigz"
            ],
            "arguments": [
                "-p",
                "16",
                "-c"
            ],
            "stdout": "$(inputs.uncompressed_file.basename).gz",
            "outputs": [
                {
                    "type": "File",
                    "id": "#gzip.cwl/compressed_file",
                    "outputBinding": {
                        "glob": "$(inputs.uncompressed_file.basename).gz"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#gzip.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "output QC-FAILED or QC-PASSED file as intermediate flag",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#qc-flag.cwl/qc_count"
                }
            ],
            "baseCommand": [
                "touch"
            ],
            "arguments": [
                {
                    "valueFrom": "${ var flag = \"\"; if (inputs.qc_count == 0) { flag = 'QC-FAILED'; } else { flag = 'QC-PASSED'; } return flag; }"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "QC-*"
                    },
                    "id": "#qc-flag.cwl/qc-flag"
                }
            ],
            "id": "#qc-flag.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "null",
                                "Directory"
                            ]
                        }
                    ],
                    "id": "#return_directory.cwl/dir_list"
                },
                {
                    "type": "string",
                    "id": "#return_directory.cwl/dir_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "null",
                                "File"
                            ]
                        }
                    ],
                    "id": "#return_directory.cwl/file_list"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#return_directory.cwl/out"
                }
            ],
            "expression": "${\n  var list2 = [];\n  var process;\n  if (inputs.file_list) { process = inputs.file_list } else { process = inputs.dir_list}\n  for (const item in process) {\n      if (process[item] != null) {\n          list2.push(process[item]) }; }\n  return {\"out\": {\n    \"class\": \"Directory\",\n    \"basename\": inputs.dir_name,\n    \"listing\": list2\n    }\n  }; }\n",
            "id": "#return_directory.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "ubuntu:latest",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "touch"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#touch_file.cwl/filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.filename)"
                    },
                    "id": "#touch_file.cwl/created_file"
                }
            ],
            "id": "#touch_file.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/5.8s_pattern"
                },
                {
                    "type": "string",
                    "id": "#main/5s_pattern"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/forward_reads"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#main/itsonedb"
                },
                {
                    "type": "string",
                    "id": "#main/itsonedb_label"
                },
                {
                    "type": "string",
                    "id": "#main/itsonedb_otu_file"
                },
                {
                    "type": "string",
                    "id": "#main/itsonedb_tax"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#main/lsu_db"
                },
                {
                    "type": "string",
                    "id": "#main/lsu_label"
                },
                {
                    "type": "string",
                    "id": "#main/lsu_otus"
                },
                {
                    "type": "string",
                    "id": "#main/lsu_tax"
                },
                {
                    "type": "int",
                    "id": "#main/qc_min_length"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/reverse_reads"
                },
                {
                    "type": "string",
                    "id": "#main/rfam_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/rfam_models"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/single_reads"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#main/ssu_db"
                },
                {
                    "type": "string",
                    "id": "#main/ssu_label"
                },
                {
                    "type": "string",
                    "id": "#main/ssu_otus"
                },
                {
                    "type": "string",
                    "id": "#main/ssu_tax"
                },
                {
                    "type": "string",
                    "id": "#main/stats_file_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#main/unite_db"
                },
                {
                    "type": "string",
                    "id": "#main/unite_label"
                },
                {
                    "type": "string",
                    "id": "#main/unite_otu_file"
                },
                {
                    "type": "string",
                    "id": "#main/unite_tax"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/after-qc/ITS-length",
                    "id": "#main/ITS-length"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/touch_file_flag/created_file",
                    "id": "#main/completed_flag_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/before-qc/fastp_filtering_json",
                    "id": "#main/fastp_filtering_json_report"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/after-qc/gz_files",
                    "pickValue": "all_non_null",
                    "id": "#main/gz_files"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/before-qc/input_files_hashsum_paired",
                    "id": "#main/hashsum_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/before-qc/input_files_hashsum_single",
                    "id": "#main/hashsum_single"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/after-qc/optional_tax_file_flag",
                    "id": "#main/no_tax_flag_file"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/before-qc/qc-statistics",
                    "id": "#main/qc-statistics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/before-qc/qc-status",
                    "id": "#main/qc-status"
                },
                {
                    "type": "File",
                    "outputSource": "#main/before-qc/qc_summary",
                    "id": "#main/qc_summary"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/after-qc/rna-count",
                    "id": "#main/rna-count"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/sequence-categorisation_folder",
                    "id": "#main/sequence-categorisation_folder"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/suppressed_upload",
                    "id": "#main/suppressed_upload"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/after-qc/taxonomy-summary_folder",
                    "id": "#main/taxonomy-summary_folder"
                }
            ],
            "steps": [
                {
                    "run": "#amplicon-2.cwl",
                    "when": "$(inputs.status.basename == 'QC-PASSED')",
                    "in": [
                        {
                            "source": "#main/5.8s_pattern",
                            "id": "#main/after-qc/5.8s_pattern"
                        },
                        {
                            "source": "#main/5s_pattern",
                            "id": "#main/after-qc/5s_pattern"
                        },
                        {
                            "source": "#main/before-qc/filtered_fasta",
                            "id": "#main/after-qc/filtered_fasta"
                        },
                        {
                            "source": "#main/itsonedb",
                            "id": "#main/after-qc/itsonedb"
                        },
                        {
                            "source": "#main/itsonedb_label",
                            "id": "#main/after-qc/itsonedb_label"
                        },
                        {
                            "source": "#main/itsonedb_otu_file",
                            "id": "#main/after-qc/itsonedb_otu_file"
                        },
                        {
                            "source": "#main/itsonedb_tax",
                            "id": "#main/after-qc/itsonedb_tax"
                        },
                        {
                            "source": "#main/lsu_db",
                            "id": "#main/after-qc/lsu_db"
                        },
                        {
                            "source": "#main/lsu_label",
                            "id": "#main/after-qc/lsu_label"
                        },
                        {
                            "source": "#main/lsu_otus",
                            "id": "#main/after-qc/lsu_otus"
                        },
                        {
                            "source": "#main/lsu_tax",
                            "id": "#main/after-qc/lsu_tax"
                        },
                        {
                            "source": "#main/rfam_model_clans",
                            "id": "#main/after-qc/rfam_model_clans"
                        },
                        {
                            "source": "#main/rfam_models",
                            "id": "#main/after-qc/rfam_models"
                        },
                        {
                            "source": "#main/ssu_db",
                            "id": "#main/after-qc/ssu_db"
                        },
                        {
                            "source": "#main/ssu_label",
                            "id": "#main/after-qc/ssu_label"
                        },
                        {
                            "source": "#main/ssu_otus",
                            "id": "#main/after-qc/ssu_otus"
                        },
                        {
                            "source": "#main/ssu_tax",
                            "id": "#main/after-qc/ssu_tax"
                        },
                        {
                            "source": "#main/before-qc/qc-status",
                            "id": "#main/after-qc/status"
                        },
                        {
                            "source": "#main/unite_db",
                            "id": "#main/after-qc/unite_db"
                        },
                        {
                            "source": "#main/unite_label",
                            "id": "#main/after-qc/unite_label"
                        },
                        {
                            "source": "#main/unite_otu_file",
                            "id": "#main/after-qc/unite_otu_file"
                        },
                        {
                            "source": "#main/unite_tax",
                            "id": "#main/after-qc/unite_tax"
                        }
                    ],
                    "out": [
                        "#main/after-qc/taxonomy-summary_folder",
                        "#main/after-qc/suppressed_upload",
                        "#main/after-qc/sequence-categorisation_folder",
                        "#main/after-qc/rna-count",
                        "#main/after-qc/gz_files",
                        "#main/after-qc/ITS-length",
                        "#main/after-qc/optional_tax_file_flag"
                    ],
                    "id": "#main/after-qc"
                },
                {
                    "run": "#amplicon-1.cwl",
                    "in": [
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/before-qc/forward_reads"
                        },
                        {
                            "source": "#main/qc_min_length",
                            "id": "#main/before-qc/qc_min_length"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/before-qc/reverse_reads"
                        },
                        {
                            "source": "#main/single_reads",
                            "id": "#main/before-qc/single_reads"
                        },
                        {
                            "source": "#main/stats_file_name",
                            "id": "#main/before-qc/stats_file_name"
                        }
                    ],
                    "out": [
                        "#main/before-qc/filtered_fasta",
                        "#main/before-qc/qc-statistics",
                        "#main/before-qc/qc_summary",
                        "#main/before-qc/qc-status",
                        "#main/before-qc/input_files_hashsum_paired",
                        "#main/before-qc/input_files_hashsum_single",
                        "#main/before-qc/fastp_filtering_json"
                    ],
                    "id": "#main/before-qc"
                },
                {
                    "when": "$(inputs.count != undefined || inputs.status.basename == \"QC-FAILED\")",
                    "run": "#touch_file.cwl",
                    "in": [
                        {
                            "source": "#main/after-qc/rna-count",
                            "id": "#main/touch_file_flag/count"
                        },
                        {
                            "default": "wf-completed",
                            "id": "#main/touch_file_flag/filename"
                        },
                        {
                            "source": "#main/before-qc/qc-status",
                            "id": "#main/touch_file_flag/status"
                        }
                    ],
                    "out": [
                        "#main/touch_file_flag/created_file"
                    ],
                    "id": "#main/touch_file_flag"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#amplicon-1.cwl/forward_reads"
                },
                {
                    "type": "int",
                    "id": "#amplicon-1.cwl/qc_min_length"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#amplicon-1.cwl/reverse_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#amplicon-1.cwl/single_reads"
                },
                {
                    "type": "string",
                    "id": "#amplicon-1.cwl/stats_file_name"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#amplicon-1.cwl/overlap_reads/fastp_report",
                    "id": "#amplicon-1.cwl/fastp_filtering_json"
                },
                {
                    "type": "File",
                    "outputSource": "#amplicon-1.cwl/run_quality_control_filtering/filtered_file",
                    "id": "#amplicon-1.cwl/filtered_fasta"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#amplicon-1.cwl/hashsum_paired/hashsum",
                    "pickValue": "all_non_null",
                    "id": "#amplicon-1.cwl/input_files_hashsum_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#amplicon-1.cwl/hashsum_single/hashsum",
                    "id": "#amplicon-1.cwl/input_files_hashsum_single"
                },
                {
                    "type": "Directory",
                    "outputSource": "#amplicon-1.cwl/qc_stats/output_dir",
                    "id": "#amplicon-1.cwl/qc-statistics"
                },
                {
                    "type": "File",
                    "outputSource": "#amplicon-1.cwl/QC-FLAG/qc-flag",
                    "id": "#amplicon-1.cwl/qc-status"
                },
                {
                    "type": "File",
                    "outputSource": "#amplicon-1.cwl/run_quality_control_filtering/stats_summary_file",
                    "id": "#amplicon-1.cwl/qc_summary"
                }
            ],
            "steps": [
                {
                    "run": "#qc-flag.cwl",
                    "in": [
                        {
                            "source": "#amplicon-1.cwl/count_processed_reads/count",
                            "id": "#amplicon-1.cwl/QC-FLAG/qc_count"
                        }
                    ],
                    "out": [
                        "#amplicon-1.cwl/QC-FLAG/qc-flag"
                    ],
                    "id": "#amplicon-1.cwl/QC-FLAG"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#amplicon-1.cwl/count_processed_reads/number"
                        },
                        {
                            "source": "#amplicon-1.cwl/run_quality_control_filtering/filtered_file",
                            "id": "#amplicon-1.cwl/count_processed_reads/sequences"
                        }
                    ],
                    "out": [
                        "#amplicon-1.cwl/count_processed_reads/count"
                    ],
                    "id": "#amplicon-1.cwl/count_processed_reads"
                },
                {
                    "run": "#generate_checksum.cwl",
                    "when": "$(inputs.single == undefined)",
                    "scatter": "#amplicon-1.cwl/hashsum_paired/input_file",
                    "in": [
                        {
                            "source": [
                                "#amplicon-1.cwl/forward_reads",
                                "#amplicon-1.cwl/reverse_reads"
                            ],
                            "id": "#amplicon-1.cwl/hashsum_paired/input_file"
                        },
                        {
                            "source": "#amplicon-1.cwl/single_reads",
                            "id": "#amplicon-1.cwl/hashsum_paired/single"
                        }
                    ],
                    "out": [
                        "#amplicon-1.cwl/hashsum_paired/hashsum"
                    ],
                    "id": "#amplicon-1.cwl/hashsum_paired"
                },
                {
                    "run": "#generate_checksum.cwl",
                    "when": "$(inputs.single != undefined)",
                    "in": [
                        {
                            "source": "#amplicon-1.cwl/single_reads",
                            "id": "#amplicon-1.cwl/hashsum_single/input_file"
                        },
                        {
                            "source": "#amplicon-1.cwl/single_reads",
                            "id": "#amplicon-1.cwl/hashsum_single/single"
                        }
                    ],
                    "out": [
                        "#amplicon-1.cwl/hashsum_single/hashsum"
                    ],
                    "id": "#amplicon-1.cwl/hashsum_single"
                },
                {
                    "label": "Paired-end overlapping reads are merged",
                    "run": "#seqprep-subwf.cwl",
                    "in": [
                        {
                            "source": "#amplicon-1.cwl/forward_reads",
                            "id": "#amplicon-1.cwl/overlap_reads/forward_reads"
                        },
                        {
                            "default": 70,
                            "id": "#amplicon-1.cwl/overlap_reads/paired_reads_length_filter"
                        },
                        {
                            "source": "#amplicon-1.cwl/reverse_reads",
                            "id": "#amplicon-1.cwl/overlap_reads/reverse_reads"
                        },
                        {
                            "source": "#amplicon-1.cwl/single_reads",
                            "id": "#amplicon-1.cwl/overlap_reads/single_reads"
                        }
                    ],
                    "out": [
                        "#amplicon-1.cwl/overlap_reads/unzipped_single_reads",
                        "#amplicon-1.cwl/overlap_reads/count_forward_submitted_reads",
                        "#amplicon-1.cwl/overlap_reads/fastp_report"
                    ],
                    "id": "#amplicon-1.cwl/overlap_reads"
                },
                {
                    "run": "#qc-stats.cwl",
                    "in": [
                        {
                            "source": "#amplicon-1.cwl/run_quality_control_filtering/filtered_file",
                            "id": "#amplicon-1.cwl/qc_stats/QCed_reads"
                        },
                        {
                            "source": "#amplicon-1.cwl/count_processed_reads/count",
                            "id": "#amplicon-1.cwl/qc_stats/sequence_count"
                        }
                    ],
                    "out": [
                        "#amplicon-1.cwl/qc_stats/output_dir",
                        "#amplicon-1.cwl/qc_stats/summary_out"
                    ],
                    "id": "#amplicon-1.cwl/qc_stats"
                },
                {
                    "run": "#qc-filtering.cwl",
                    "in": [
                        {
                            "default": "fasta",
                            "id": "#amplicon-1.cwl/run_quality_control_filtering/input_file_format"
                        },
                        {
                            "source": "#amplicon-1.cwl/qc_min_length",
                            "id": "#amplicon-1.cwl/run_quality_control_filtering/min_length"
                        },
                        {
                            "source": "#amplicon-1.cwl/trimming/trimmed_and_reformatted_reads",
                            "id": "#amplicon-1.cwl/run_quality_control_filtering/seq_file"
                        },
                        {
                            "default": "qc_summary",
                            "id": "#amplicon-1.cwl/run_quality_control_filtering/stats_file_name"
                        },
                        {
                            "source": "#amplicon-1.cwl/overlap_reads/count_forward_submitted_reads",
                            "id": "#amplicon-1.cwl/run_quality_control_filtering/submitted_seq_count"
                        }
                    ],
                    "out": [
                        "#amplicon-1.cwl/run_quality_control_filtering/filtered_file",
                        "#amplicon-1.cwl/run_quality_control_filtering/stats_summary_file"
                    ],
                    "id": "#amplicon-1.cwl/run_quality_control_filtering"
                },
                {
                    "run": "#trim_and_reformat_reads.cwl",
                    "in": [
                        {
                            "source": "#amplicon-1.cwl/overlap_reads/unzipped_single_reads",
                            "id": "#amplicon-1.cwl/trimming/reads"
                        }
                    ],
                    "out": [
                        "#amplicon-1.cwl/trimming/trimmed_and_reformatted_reads"
                    ],
                    "id": "#amplicon-1.cwl/trimming"
                }
            ],
            "id": "#amplicon-1.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/5.8s_pattern"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/5s_pattern"
                },
                {
                    "type": "File",
                    "id": "#amplicon-2.cwl/filtered_fasta"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#amplicon-2.cwl/itsonedb"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/itsonedb_label"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/itsonedb_otu_file"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/itsonedb_tax"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#amplicon-2.cwl/lsu_db"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/lsu_label"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/lsu_otus"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/lsu_tax"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/rfam_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#amplicon-2.cwl/rfam_models"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#amplicon-2.cwl/ssu_db"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/ssu_label"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/ssu_otus"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/ssu_tax"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#amplicon-2.cwl/unite_db"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/unite_label"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/unite_otu_file"
                },
                {
                    "type": "string",
                    "id": "#amplicon-2.cwl/unite_tax"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#amplicon-2.cwl/suppress_tax/its_length",
                    "id": "#amplicon-2.cwl/ITS-length"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#amplicon-2.cwl/gzip_files/compressed_file",
                    "id": "#amplicon-2.cwl/gz_files"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#amplicon-2.cwl/no_tax_file_flag/created_file",
                    "id": "#amplicon-2.cwl/optional_tax_file_flag"
                },
                {
                    "type": "File",
                    "outputSource": "#amplicon-2.cwl/rna_prediction/LSU-SSU-count",
                    "id": "#amplicon-2.cwl/rna-count"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#amplicon-2.cwl/return_seq_dir/out",
                    "id": "#amplicon-2.cwl/sequence-categorisation_folder"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#amplicon-2.cwl/suppress_tax/out_suppress",
                    "id": "#amplicon-2.cwl/suppressed_upload"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#amplicon-2.cwl/suppress_tax/out_tax",
                    "id": "#amplicon-2.cwl/taxonomy-summary_folder"
                }
            ],
            "steps": [
                {
                    "run": "#ITS-wf.cwl",
                    "in": [
                        {
                            "source": "#amplicon-2.cwl/rna_prediction/LSU_coords",
                            "id": "#amplicon-2.cwl/ITS/LSU_coordinates"
                        },
                        {
                            "source": "#amplicon-2.cwl/rna_prediction/SSU_coords",
                            "id": "#amplicon-2.cwl/ITS/SSU_coordinates"
                        },
                        {
                            "source": "#amplicon-2.cwl/itsonedb",
                            "id": "#amplicon-2.cwl/ITS/itsone_database"
                        },
                        {
                            "source": "#amplicon-2.cwl/itsonedb_otu_file",
                            "id": "#amplicon-2.cwl/ITS/itsone_otus"
                        },
                        {
                            "source": "#amplicon-2.cwl/itsonedb_tax",
                            "id": "#amplicon-2.cwl/ITS/itsone_taxonomy"
                        },
                        {
                            "source": "#amplicon-2.cwl/itsonedb_label",
                            "id": "#amplicon-2.cwl/ITS/otu_itsone_label"
                        },
                        {
                            "source": "#amplicon-2.cwl/unite_label",
                            "id": "#amplicon-2.cwl/ITS/otu_unite_label"
                        },
                        {
                            "source": "#amplicon-2.cwl/filtered_fasta",
                            "id": "#amplicon-2.cwl/ITS/query_sequences"
                        },
                        {
                            "source": "#amplicon-2.cwl/unite_db",
                            "id": "#amplicon-2.cwl/ITS/unite_database"
                        },
                        {
                            "source": "#amplicon-2.cwl/unite_otu_file",
                            "id": "#amplicon-2.cwl/ITS/unite_otus"
                        },
                        {
                            "source": "#amplicon-2.cwl/unite_tax",
                            "id": "#amplicon-2.cwl/ITS/unite_taxonomy"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/ITS/unite_folder",
                        "#amplicon-2.cwl/ITS/itsonedb_folder",
                        "#amplicon-2.cwl/ITS/number_ITS_seqs",
                        "#amplicon-2.cwl/ITS/masking_file"
                    ],
                    "id": "#amplicon-2.cwl/ITS"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#amplicon-2.cwl/rna_prediction/LSU_fasta",
                            "id": "#amplicon-2.cwl/gzip_LSU/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/gzip_LSU/compressed_file"
                    ],
                    "id": "#amplicon-2.cwl/gzip_LSU"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#amplicon-2.cwl/rna_prediction/SSU_fasta",
                            "id": "#amplicon-2.cwl/gzip_SSU/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/gzip_SSU/compressed_file"
                    ],
                    "id": "#amplicon-2.cwl/gzip_SSU"
                },
                {
                    "run": "#gzip.cwl",
                    "scatter": "#amplicon-2.cwl/gzip_files/uncompressed_file",
                    "in": [
                        {
                            "source": [
                                "#amplicon-2.cwl/filtered_fasta",
                                "#amplicon-2.cwl/rna_prediction/cmsearch_result",
                                "#amplicon-2.cwl/rna_prediction/ncRNA"
                            ],
                            "id": "#amplicon-2.cwl/gzip_files/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/gzip_files/compressed_file"
                    ],
                    "id": "#amplicon-2.cwl/gzip_files"
                },
                {
                    "when": "$(inputs.folder == null )",
                    "run": "#touch_file.cwl",
                    "in": [
                        {
                            "default": "no-tax",
                            "id": "#amplicon-2.cwl/no_tax_file_flag/filename"
                        },
                        {
                            "source": "#amplicon-2.cwl/suppress_tax/out_tax",
                            "id": "#amplicon-2.cwl/no_tax_file_flag/folder"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/no_tax_file_flag/created_file"
                    ],
                    "id": "#amplicon-2.cwl/no_tax_file_flag"
                },
                {
                    "when": "$(inputs.unite_folder != null && inputs.itsonedb_folder != null)",
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "source": [
                                "#amplicon-2.cwl/ITS/unite_folder",
                                "#amplicon-2.cwl/ITS/itsonedb_folder"
                            ],
                            "id": "#amplicon-2.cwl/return_its_dir/dir_list"
                        },
                        {
                            "default": "its",
                            "id": "#amplicon-2.cwl/return_its_dir/dir_name"
                        },
                        {
                            "source": "#amplicon-2.cwl/ITS/itsonedb_folder",
                            "id": "#amplicon-2.cwl/return_its_dir/itsonedb_folder"
                        },
                        {
                            "source": "#amplicon-2.cwl/ITS/unite_folder",
                            "id": "#amplicon-2.cwl/return_its_dir/unite_folder"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/return_its_dir/out"
                    ],
                    "id": "#amplicon-2.cwl/return_its_dir"
                },
                {
                    "run": "#return_directory.cwl",
                    "when": "$(inputs.rna != null || inputs.tax != null )",
                    "in": [
                        {
                            "default": "sequence-categorisation",
                            "id": "#amplicon-2.cwl/return_seq_dir/dir_name"
                        },
                        {
                            "source": [
                                "#amplicon-2.cwl/rna_prediction/compressed_rnas",
                                "#amplicon-2.cwl/suppress_tax/out_fastas_tax"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#amplicon-2.cwl/return_seq_dir/file_list"
                        },
                        {
                            "source": "#amplicon-2.cwl/rna_prediction/compressed_rnas",
                            "id": "#amplicon-2.cwl/return_seq_dir/rna"
                        },
                        {
                            "source": "#amplicon-2.cwl/suppress_tax/out_fastas_tax",
                            "id": "#amplicon-2.cwl/return_seq_dir/tax"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/return_seq_dir/out"
                    ],
                    "id": "#amplicon-2.cwl/return_seq_dir"
                },
                {
                    "run": "#rna_prediction-sub-wf.cwl",
                    "in": [
                        {
                            "source": "#amplicon-2.cwl/filtered_fasta",
                            "id": "#amplicon-2.cwl/rna_prediction/input_sequences"
                        },
                        {
                            "source": "#amplicon-2.cwl/rfam_model_clans",
                            "id": "#amplicon-2.cwl/rna_prediction/ncRNA_ribosomal_model_clans"
                        },
                        {
                            "source": "#amplicon-2.cwl/rfam_models",
                            "id": "#amplicon-2.cwl/rna_prediction/ncRNA_ribosomal_models"
                        },
                        {
                            "source": "#amplicon-2.cwl/5.8s_pattern",
                            "id": "#amplicon-2.cwl/rna_prediction/pattern_5.8S"
                        },
                        {
                            "source": "#amplicon-2.cwl/5s_pattern",
                            "id": "#amplicon-2.cwl/rna_prediction/pattern_5S"
                        },
                        {
                            "source": "#amplicon-2.cwl/lsu_label",
                            "id": "#amplicon-2.cwl/rna_prediction/pattern_LSU"
                        },
                        {
                            "source": "#amplicon-2.cwl/ssu_label",
                            "id": "#amplicon-2.cwl/rna_prediction/pattern_SSU"
                        },
                        {
                            "source": "#amplicon-2.cwl/lsu_db",
                            "id": "#amplicon-2.cwl/rna_prediction/silva_lsu_database"
                        },
                        {
                            "source": "#amplicon-2.cwl/lsu_otus",
                            "id": "#amplicon-2.cwl/rna_prediction/silva_lsu_otus"
                        },
                        {
                            "source": "#amplicon-2.cwl/lsu_tax",
                            "id": "#amplicon-2.cwl/rna_prediction/silva_lsu_taxonomy"
                        },
                        {
                            "source": "#amplicon-2.cwl/ssu_db",
                            "id": "#amplicon-2.cwl/rna_prediction/silva_ssu_database"
                        },
                        {
                            "source": "#amplicon-2.cwl/ssu_otus",
                            "id": "#amplicon-2.cwl/rna_prediction/silva_ssu_otus"
                        },
                        {
                            "source": "#amplicon-2.cwl/ssu_tax",
                            "id": "#amplicon-2.cwl/rna_prediction/silva_ssu_taxonomy"
                        },
                        {
                            "default": "raw",
                            "id": "#amplicon-2.cwl/rna_prediction/type"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/rna_prediction/ncRNA",
                        "#amplicon-2.cwl/rna_prediction/cmsearch_result",
                        "#amplicon-2.cwl/rna_prediction/LSU-SSU-count",
                        "#amplicon-2.cwl/rna_prediction/SSU_folder",
                        "#amplicon-2.cwl/rna_prediction/LSU_folder",
                        "#amplicon-2.cwl/rna_prediction/SSU_coords",
                        "#amplicon-2.cwl/rna_prediction/LSU_coords",
                        "#amplicon-2.cwl/rna_prediction/SSU_fasta",
                        "#amplicon-2.cwl/rna_prediction/LSU_fasta",
                        "#amplicon-2.cwl/rna_prediction/compressed_rnas",
                        "#amplicon-2.cwl/rna_prediction/number_LSU_mapseq",
                        "#amplicon-2.cwl/rna_prediction/number_SSU_mapseq"
                    ],
                    "id": "#amplicon-2.cwl/rna_prediction"
                },
                {
                    "run": "#suppress_tax.cwl",
                    "in": [
                        {
                            "source": "#amplicon-2.cwl/return_its_dir/out",
                            "id": "#amplicon-2.cwl/suppress_tax/its_dir"
                        },
                        {
                            "source": "#amplicon-2.cwl/ITS/masking_file",
                            "id": "#amplicon-2.cwl/suppress_tax/its_file"
                        },
                        {
                            "source": "#amplicon-2.cwl/rna_prediction/LSU_folder",
                            "id": "#amplicon-2.cwl/suppress_tax/lsu_dir"
                        },
                        {
                            "source": "#amplicon-2.cwl/gzip_LSU/compressed_file",
                            "id": "#amplicon-2.cwl/suppress_tax/lsu_file"
                        },
                        {
                            "source": "#amplicon-2.cwl/rna_prediction/SSU_folder",
                            "id": "#amplicon-2.cwl/suppress_tax/ssu_dir"
                        },
                        {
                            "source": "#amplicon-2.cwl/gzip_SSU/compressed_file",
                            "id": "#amplicon-2.cwl/suppress_tax/ssu_file"
                        }
                    ],
                    "out": [
                        "#amplicon-2.cwl/suppress_tax/its_length",
                        "#amplicon-2.cwl/suppress_tax/out_tax",
                        "#amplicon-2.cwl/suppress_tax/out_suppress",
                        "#amplicon-2.cwl/suppress_tax/out_fastas_tax"
                    ],
                    "id": "#amplicon-2.cwl/suppress_tax"
                }
            ],
            "id": "#amplicon-2.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "ITS SubWorkflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#ITS-wf.cwl/LSU_coordinates"
                },
                {
                    "type": "File",
                    "id": "#ITS-wf.cwl/SSU_coordinates"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#ITS-wf.cwl/itsone_database"
                },
                {
                    "type": "string",
                    "id": "#ITS-wf.cwl/itsone_otus"
                },
                {
                    "type": "string",
                    "id": "#ITS-wf.cwl/itsone_taxonomy"
                },
                {
                    "type": "string",
                    "id": "#ITS-wf.cwl/otu_itsone_label"
                },
                {
                    "type": "string",
                    "id": "#ITS-wf.cwl/otu_unite_label"
                },
                {
                    "type": "File",
                    "id": "#ITS-wf.cwl/query_sequences"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#ITS-wf.cwl/unite_database"
                },
                {
                    "type": "string",
                    "id": "#ITS-wf.cwl/unite_otus"
                },
                {
                    "type": "string",
                    "id": "#ITS-wf.cwl/unite_taxonomy"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#ITS-wf.cwl/run_itsonedb/out_dir",
                    "id": "#ITS-wf.cwl/itsonedb_folder"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#ITS-wf.cwl/gzip_masked_ITS/compressed_file",
                    "id": "#ITS-wf.cwl/masking_file"
                },
                {
                    "type": "int",
                    "outputSource": "#ITS-wf.cwl/count_ITS_seqs/count",
                    "id": "#ITS-wf.cwl/number_ITS_seqs"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#ITS-wf.cwl/run_unite/out_dir",
                    "id": "#ITS-wf.cwl/unite_folder"
                }
            ],
            "steps": [
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": [
                                "#ITS-wf.cwl/SSU_coordinates",
                                "#ITS-wf.cwl/LSU_coordinates"
                            ],
                            "id": "#ITS-wf.cwl/cat/files"
                        },
                        {
                            "default": "SSU-and",
                            "id": "#ITS-wf.cwl/cat/outputFileName"
                        },
                        {
                            "default": "-LSU",
                            "id": "#ITS-wf.cwl/cat/postfix"
                        }
                    ],
                    "out": [
                        "#ITS-wf.cwl/cat/result"
                    ],
                    "id": "#ITS-wf.cwl/cat"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#ITS-wf.cwl/count_ITS_seqs/number"
                        },
                        {
                            "source": "#ITS-wf.cwl/mask_for_ITS/masked_sequences",
                            "id": "#ITS-wf.cwl/count_ITS_seqs/sequences"
                        }
                    ],
                    "out": [
                        "#ITS-wf.cwl/count_ITS_seqs/count"
                    ],
                    "id": "#ITS-wf.cwl/count_ITS_seqs"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#ITS-wf.cwl/count_masked_fasta/number"
                        },
                        {
                            "source": "#ITS-wf.cwl/mask_for_ITS/masked_sequences",
                            "id": "#ITS-wf.cwl/count_masked_fasta/sequences"
                        }
                    ],
                    "out": [
                        "#ITS-wf.cwl/count_masked_fasta/count"
                    ],
                    "id": "#ITS-wf.cwl/count_masked_fasta"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#ITS-wf.cwl/mask_for_ITS/masked_sequences",
                            "id": "#ITS-wf.cwl/gzip_masked_ITS/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#ITS-wf.cwl/gzip_masked_ITS/compressed_file"
                    ],
                    "id": "#ITS-wf.cwl/gzip_masked_ITS"
                },
                {
                    "run": "#bedtools.cwl",
                    "in": [
                        {
                            "source": "#ITS-wf.cwl/reformat_coords/maskfile",
                            "id": "#ITS-wf.cwl/mask_for_ITS/maskfile"
                        },
                        {
                            "source": "#ITS-wf.cwl/query_sequences",
                            "id": "#ITS-wf.cwl/mask_for_ITS/sequences"
                        }
                    ],
                    "out": [
                        "#ITS-wf.cwl/mask_for_ITS/masked_sequences"
                    ],
                    "id": "#ITS-wf.cwl/mask_for_ITS"
                },
                {
                    "run": "#format-bedfile.cwl",
                    "in": [
                        {
                            "source": "#ITS-wf.cwl/cat/result",
                            "id": "#ITS-wf.cwl/reformat_coords/all_coordinates"
                        }
                    ],
                    "out": [
                        "#ITS-wf.cwl/reformat_coords/maskfile"
                    ],
                    "id": "#ITS-wf.cwl/reformat_coords"
                },
                {
                    "when": "$(inputs.fasta_count > 0)",
                    "run": "#classify-otu-visualise.cwl",
                    "in": [
                        {
                            "source": "#ITS-wf.cwl/mask_for_ITS/masked_sequences",
                            "id": "#ITS-wf.cwl/run_itsonedb/fasta"
                        },
                        {
                            "source": "#ITS-wf.cwl/count_masked_fasta/count",
                            "id": "#ITS-wf.cwl/run_itsonedb/fasta_count"
                        },
                        {
                            "source": "#ITS-wf.cwl/query_sequences",
                            "id": "#ITS-wf.cwl/run_itsonedb/file_for_prefix"
                        },
                        {
                            "source": "#ITS-wf.cwl/itsone_database",
                            "id": "#ITS-wf.cwl/run_itsonedb/mapseq_ref"
                        },
                        {
                            "source": "#ITS-wf.cwl/itsone_taxonomy",
                            "id": "#ITS-wf.cwl/run_itsonedb/mapseq_taxonomy"
                        },
                        {
                            "source": "#ITS-wf.cwl/otu_itsone_label",
                            "id": "#ITS-wf.cwl/run_itsonedb/otu_label"
                        },
                        {
                            "source": "#ITS-wf.cwl/itsone_otus",
                            "id": "#ITS-wf.cwl/run_itsonedb/otu_ref"
                        },
                        {
                            "default": "itsonedb",
                            "id": "#ITS-wf.cwl/run_itsonedb/return_dirname"
                        }
                    ],
                    "out": [
                        "#ITS-wf.cwl/run_itsonedb/out_dir"
                    ],
                    "id": "#ITS-wf.cwl/run_itsonedb"
                },
                {
                    "when": "$(inputs.fasta_count > 0)",
                    "run": "#classify-otu-visualise.cwl",
                    "in": [
                        {
                            "source": "#ITS-wf.cwl/mask_for_ITS/masked_sequences",
                            "id": "#ITS-wf.cwl/run_unite/fasta"
                        },
                        {
                            "source": "#ITS-wf.cwl/count_masked_fasta/count",
                            "id": "#ITS-wf.cwl/run_unite/fasta_count"
                        },
                        {
                            "source": "#ITS-wf.cwl/query_sequences",
                            "id": "#ITS-wf.cwl/run_unite/file_for_prefix"
                        },
                        {
                            "source": "#ITS-wf.cwl/unite_database",
                            "id": "#ITS-wf.cwl/run_unite/mapseq_ref"
                        },
                        {
                            "source": "#ITS-wf.cwl/unite_taxonomy",
                            "id": "#ITS-wf.cwl/run_unite/mapseq_taxonomy"
                        },
                        {
                            "source": "#ITS-wf.cwl/otu_unite_label",
                            "id": "#ITS-wf.cwl/run_unite/otu_label"
                        },
                        {
                            "source": "#ITS-wf.cwl/unite_otus",
                            "id": "#ITS-wf.cwl/run_unite/otu_ref"
                        },
                        {
                            "default": "unite",
                            "id": "#ITS-wf.cwl/run_unite/return_dirname"
                        }
                    ],
                    "out": [
                        "#ITS-wf.cwl/run_unite/out_dir"
                    ],
                    "id": "#ITS-wf.cwl/run_unite"
                }
            ],
            "id": "#ITS-wf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Trim and reformat reads (single and paired end version)",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#trim_and_reformat_reads.cwl/reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": [
                        "#trim_and_reformat_reads.cwl/trimming/trimmed_and_reformatted_reads",
                        "#trim_and_reformat_reads.cwl/touch_empty_fasta/created_file"
                    ],
                    "pickValue": "first_non_null",
                    "id": "#trim_and_reformat_reads.cwl/trimmed_and_reformatted_reads"
                }
            ],
            "steps": [
                {
                    "run": "#count_lines.cwl",
                    "in": [
                        {
                            "default": 4,
                            "id": "#trim_and_reformat_reads.cwl/count_overlapped_reads/number"
                        },
                        {
                            "source": "#trim_and_reformat_reads.cwl/reads",
                            "id": "#trim_and_reformat_reads.cwl/count_overlapped_reads/sequences"
                        }
                    ],
                    "out": [
                        "#trim_and_reformat_reads.cwl/count_overlapped_reads/count"
                    ],
                    "id": "#trim_and_reformat_reads.cwl/count_overlapped_reads"
                },
                {
                    "when": "$(inputs.fastq_count == 0)",
                    "run": "#touch_file.cwl",
                    "in": [
                        {
                            "source": "#trim_and_reformat_reads.cwl/count_overlapped_reads/count",
                            "id": "#trim_and_reformat_reads.cwl/touch_empty_fasta/fastq_count"
                        },
                        {
                            "default": "empty.fasta",
                            "id": "#trim_and_reformat_reads.cwl/touch_empty_fasta/filename"
                        }
                    ],
                    "out": [
                        "#trim_and_reformat_reads.cwl/touch_empty_fasta/created_file"
                    ],
                    "id": "#trim_and_reformat_reads.cwl/touch_empty_fasta"
                },
                {
                    "run": "#trimming-not-empty-subwf.cwl",
                    "when": "$(inputs.fastq_count != 0)",
                    "in": [
                        {
                            "source": "#trim_and_reformat_reads.cwl/count_overlapped_reads/count",
                            "id": "#trim_and_reformat_reads.cwl/trimming/fastq_count"
                        },
                        {
                            "source": "#trim_and_reformat_reads.cwl/reads",
                            "id": "#trim_and_reformat_reads.cwl/trimming/not_empty_reads"
                        }
                    ],
                    "out": [
                        "#trim_and_reformat_reads.cwl/trimming/trimmed_and_reformatted_reads"
                    ],
                    "id": "#trim_and_reformat_reads.cwl/trimming"
                }
            ],
            "id": "#trim_and_reformat_reads.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Trim and reformat reads (single and paired end version)",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#trimming-not-empty-subwf.cwl/not_empty_reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#trimming-not-empty-subwf.cwl/clean_fasta_headers/sequences_with_cleaned_headers",
                    "id": "#trimming-not-empty-subwf.cwl/trimmed_and_reformatted_reads"
                }
            ],
            "steps": [
                {
                    "run": "#clean_fasta_headers.cwl",
                    "in": [
                        {
                            "source": "#trimming-not-empty-subwf.cwl/convert_trimmed_reads_to_fasta/fasta",
                            "id": "#trimming-not-empty-subwf.cwl/clean_fasta_headers/sequences"
                        }
                    ],
                    "out": [
                        "#trimming-not-empty-subwf.cwl/clean_fasta_headers/sequences_with_cleaned_headers"
                    ],
                    "id": "#trimming-not-empty-subwf.cwl/clean_fasta_headers"
                },
                {
                    "in": [
                        {
                            "source": "#trimming-not-empty-subwf.cwl/trim_quality_control/reads1_trimmed",
                            "id": "#trimming-not-empty-subwf.cwl/combine_trimmed/files"
                        },
                        {
                            "source": "#trimming-not-empty-subwf.cwl/not_empty_reads",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#trimming-not-empty-subwf.cwl/combine_trimmed/outputFileName"
                        },
                        {
                            "default": ".trimmed",
                            "id": "#trimming-not-empty-subwf.cwl/combine_trimmed/postfix"
                        }
                    ],
                    "out": [
                        "#trimming-not-empty-subwf.cwl/combine_trimmed/result"
                    ],
                    "run": "#concatenate.cwl",
                    "id": "#trimming-not-empty-subwf.cwl/combine_trimmed"
                },
                {
                    "run": "#fastq_to_fasta.cwl",
                    "in": [
                        {
                            "source": "#trimming-not-empty-subwf.cwl/combine_trimmed/result",
                            "id": "#trimming-not-empty-subwf.cwl/convert_trimmed_reads_to_fasta/fastq"
                        }
                    ],
                    "out": [
                        "#trimming-not-empty-subwf.cwl/convert_trimmed_reads_to_fasta/fasta"
                    ],
                    "id": "#trimming-not-empty-subwf.cwl/convert_trimmed_reads_to_fasta"
                },
                {
                    "in": [
                        {
                            "default": 1000000,
                            "id": "#trimming-not-empty-subwf.cwl/split_seqs/chunk_size"
                        },
                        {
                            "default": "fastq",
                            "id": "#trimming-not-empty-subwf.cwl/split_seqs/file_format"
                        },
                        {
                            "source": "#trimming-not-empty-subwf.cwl/not_empty_reads",
                            "id": "#trimming-not-empty-subwf.cwl/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#trimming-not-empty-subwf.cwl/split_seqs/chunks"
                    ],
                    "run": "#protein_chunker.cwl",
                    "id": "#trimming-not-empty-subwf.cwl/split_seqs"
                },
                {
                    "doc": "Low quality trimming (low quality ends and sequences with < quality scores\nless than 15 over a 4 nucleotide wide window are removed)\n",
                    "run": "#Trimmomatic-v0.36-SE.cwl",
                    "scatter": "#trimming-not-empty-subwf.cwl/trim_quality_control/reads1",
                    "in": [
                        {
                            "default": "SE",
                            "id": "#trimming-not-empty-subwf.cwl/trim_quality_control/end_mode"
                        },
                        {
                            "default": 3,
                            "id": "#trimming-not-empty-subwf.cwl/trim_quality_control/leading"
                        },
                        {
                            "default": 100,
                            "id": "#trimming-not-empty-subwf.cwl/trim_quality_control/minlen"
                        },
                        {
                            "default": "33",
                            "id": "#trimming-not-empty-subwf.cwl/trim_quality_control/phred"
                        },
                        {
                            "source": "#trimming-not-empty-subwf.cwl/split_seqs/chunks",
                            "id": "#trimming-not-empty-subwf.cwl/trim_quality_control/reads1"
                        },
                        {
                            "default": "4:15",
                            "id": "#trimming-not-empty-subwf.cwl/trim_quality_control/slidingwindow"
                        },
                        {
                            "default": 3,
                            "id": "#trimming-not-empty-subwf.cwl/trim_quality_control/trailing"
                        }
                    ],
                    "out": [
                        "#trimming-not-empty-subwf.cwl/trim_quality_control/reads1_trimmed"
                    ],
                    "id": "#trimming-not-empty-subwf.cwl/trim_quality_control"
                }
            ],
            "id": "#trimming-not-empty-subwf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Identifies non-coding RNAs using Rfams covariance models",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#cmsearch-multimodel-assembly.cwl/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#cmsearch-multimodel-assembly.cwl/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-multimodel-assembly.cwl/query_sequences"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/result",
                    "type": "File",
                    "id": "#cmsearch-multimodel-assembly.cwl/concatenate_matches"
                },
                {
                    "outputSource": "#cmsearch-multimodel-assembly.cwl/remove_overlaps/deoverlapped_matches",
                    "type": "File",
                    "id": "#cmsearch-multimodel-assembly.cwl/deoverlapped_matches"
                },
                {
                    "outputSource": "#cmsearch-multimodel-assembly.cwl/cmsearch/matches",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#cmsearch-multimodel-assembly.cwl/matches"
                }
            ],
            "steps": [
                {
                    "label": "Search sequence(s) against a covariance model database",
                    "run": "#infernal-cmsearch-v1.1.2.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/covariance_models",
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/covariance_model_database"
                        },
                        {
                            "default": 8,
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/cpu"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/only_hmm"
                        },
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/query_sequences",
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/query_sequences"
                        },
                        {
                            "default": 1000,
                            "id": "#cmsearch-multimodel-assembly.cwl/cmsearch/search_space_size"
                        }
                    ],
                    "scatter": "#cmsearch-multimodel-assembly.cwl/cmsearch/covariance_model_database",
                    "out": [
                        "#cmsearch-multimodel-assembly.cwl/cmsearch/matches",
                        "#cmsearch-multimodel-assembly.cwl/cmsearch/programOutput"
                    ],
                    "id": "#cmsearch-multimodel-assembly.cwl/cmsearch"
                },
                {
                    "label": "Remove lower scoring overlaps from cmsearch --tblout files.",
                    "run": "#cmsearch-deoverlap-v0.02.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/clan_info",
                            "id": "#cmsearch-multimodel-assembly.cwl/remove_overlaps/clan_information"
                        },
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/result",
                            "id": "#cmsearch-multimodel-assembly.cwl/remove_overlaps/cmsearch_matches"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-assembly.cwl/remove_overlaps/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-multimodel-assembly.cwl/remove_overlaps"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": [
                                "#cmsearch-multimodel-assembly.cwl/cmsearch/matches"
                            ],
                            "id": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/files"
                        },
                        {
                            "source": "#cmsearch-multimodel-assembly.cwl/query_sequences",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/outputFileName"
                        },
                        {
                            "default": ".cmsearch.all.tblout",
                            "id": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/postfix"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches/result"
                    ],
                    "id": "#cmsearch-multimodel-assembly.cwl/run_concatenate_matches"
                }
            ],
            "id": "#cmsearch-multimodel-assembly.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Arnaud Meng, Maxim Scheremetjew, Ekaterina Sakharova",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Run taxonomic classification, create OTU table and krona visualisation",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#classify-otu-visualise.cwl/fasta"
                },
                {
                    "type": "File",
                    "id": "#classify-otu-visualise.cwl/file_for_prefix"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#classify-otu-visualise.cwl/mapseq_ref"
                },
                {
                    "type": "string",
                    "id": "#classify-otu-visualise.cwl/mapseq_taxonomy"
                },
                {
                    "type": "string",
                    "id": "#classify-otu-visualise.cwl/otu_label"
                },
                {
                    "type": "string",
                    "id": "#classify-otu-visualise.cwl/otu_ref"
                },
                {
                    "type": "string",
                    "id": "#classify-otu-visualise.cwl/return_dirname"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputSource": "#classify-otu-visualise.cwl/count_lines_mapseq/number",
                    "id": "#classify-otu-visualise.cwl/number_lines_mapseq"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#classify-otu-visualise.cwl/return_output_dir/out",
                    "id": "#classify-otu-visualise.cwl/out_dir"
                }
            ],
            "steps": [
                {
                    "run": "#mapseq2biom.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/otu_label",
                            "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts/label"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/otu_ref",
                            "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_table"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq/classifications",
                            "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts/query"
                        },
                        {
                            "default": true,
                            "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts/taxid_flag"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv",
                        "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_txt",
                        "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv_notaxid"
                    ],
                    "id": "#classify-otu-visualise.cwl/classifications_to_otu_counts"
                },
                {
                    "run": "#gzip.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq/classifications",
                            "id": "#classify-otu-visualise.cwl/compress_mapseq/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/compress_mapseq/compressed_file"
                    ],
                    "label": "gzip mapseq output",
                    "id": "#classify-otu-visualise.cwl/compress_mapseq"
                },
                {
                    "run": "#count_number_lines.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq/classifications",
                            "id": "#classify-otu-visualise.cwl/count_lines_mapseq/input_file"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/count_lines_mapseq/number"
                    ],
                    "id": "#classify-otu-visualise.cwl/count_lines_mapseq"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv_notaxid",
                            "id": "#classify-otu-visualise.cwl/counts_to_hdf5/biom"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/count_lines_mapseq/number",
                            "id": "#classify-otu-visualise.cwl/counts_to_hdf5/count"
                        },
                        {
                            "default": true,
                            "id": "#classify-otu-visualise.cwl/counts_to_hdf5/hdf5"
                        },
                        {
                            "default": "OTU table",
                            "id": "#classify-otu-visualise.cwl/counts_to_hdf5/table_type"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/counts_to_hdf5/result"
                    ],
                    "id": "#classify-otu-visualise.cwl/counts_to_hdf5"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv_notaxid",
                            "id": "#classify-otu-visualise.cwl/counts_to_json/biom"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/count_lines_mapseq/number",
                            "id": "#classify-otu-visualise.cwl/counts_to_json/count"
                        },
                        {
                            "default": true,
                            "id": "#classify-otu-visualise.cwl/counts_to_json/json"
                        },
                        {
                            "default": "OTU table",
                            "id": "#classify-otu-visualise.cwl/counts_to_json/table_type"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/counts_to_json/result"
                    ],
                    "id": "#classify-otu-visualise.cwl/counts_to_json"
                },
                {
                    "run": "#mapseq.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq_ref",
                            "id": "#classify-otu-visualise.cwl/mapseq/database"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/file_for_prefix",
                            "id": "#classify-otu-visualise.cwl/mapseq/prefix"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/fasta",
                            "id": "#classify-otu-visualise.cwl/mapseq/sequences"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/mapseq_taxonomy",
                            "id": "#classify-otu-visualise.cwl/mapseq/taxonomy"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/mapseq/classifications"
                    ],
                    "id": "#classify-otu-visualise.cwl/mapseq"
                },
                {
                    "when": "$(inputs.count > 2)",
                    "run": "#return_directory.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/count_lines_mapseq/number",
                            "id": "#classify-otu-visualise.cwl/return_output_dir/count"
                        },
                        {
                            "source": "#classify-otu-visualise.cwl/return_dirname",
                            "id": "#classify-otu-visualise.cwl/return_output_dir/dir_name"
                        },
                        {
                            "source": [
                                "#classify-otu-visualise.cwl/compress_mapseq/compressed_file",
                                "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_tsv",
                                "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_txt",
                                "#classify-otu-visualise.cwl/visualize_otu_counts/otu_visualization",
                                "#classify-otu-visualise.cwl/counts_to_hdf5/result",
                                "#classify-otu-visualise.cwl/counts_to_json/result"
                            ],
                            "id": "#classify-otu-visualise.cwl/return_output_dir/file_list"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/return_output_dir/out"
                    ],
                    "label": "return all files in one folder",
                    "id": "#classify-otu-visualise.cwl/return_output_dir"
                },
                {
                    "run": "#krona.cwl",
                    "in": [
                        {
                            "source": "#classify-otu-visualise.cwl/classifications_to_otu_counts/otu_txt",
                            "id": "#classify-otu-visualise.cwl/visualize_otu_counts/otu_counts"
                        }
                    ],
                    "out": [
                        "#classify-otu-visualise.cwl/visualize_otu_counts/otu_visualization"
                    ],
                    "id": "#classify-otu-visualise.cwl/visualize_otu_counts"
                }
            ],
            "id": "#classify-otu-visualise.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Identifies non-coding RNAs using Rfams covariance models",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#cmsearch-condition.cwl/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#cmsearch-condition.cwl/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-condition.cwl/query_sequences"
                },
                {
                    "type": "string",
                    "id": "#cmsearch-condition.cwl/type"
                }
            ],
            "outputs": [
                {
                    "outputSource": [
                        "#cmsearch-condition.cwl/cmsearch_assembly/concatenate_matches",
                        "#cmsearch-condition.cwl/cmsearch_raw_data/concatenate_matches"
                    ],
                    "pickValue": "first_non_null",
                    "type": "File",
                    "id": "#cmsearch-condition.cwl/concatenate_matches"
                },
                {
                    "outputSource": [
                        "#cmsearch-condition.cwl/cmsearch_assembly/deoverlapped_matches",
                        "#cmsearch-condition.cwl/cmsearch_raw_data/deoverlapped_matches"
                    ],
                    "pickValue": "first_non_null",
                    "type": "File",
                    "id": "#cmsearch-condition.cwl/deoverlapped_matches"
                }
            ],
            "steps": [
                {
                    "when": "$(inputs.type == 'assembly')",
                    "label": "Search sequence(s) against a covariance model database for assemblies",
                    "run": "#cmsearch-multimodel-assembly.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-condition.cwl/clan_info",
                            "id": "#cmsearch-condition.cwl/cmsearch_assembly/clan_info"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/covariance_models",
                            "id": "#cmsearch-condition.cwl/cmsearch_assembly/covariance_models"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/query_sequences",
                            "id": "#cmsearch-condition.cwl/cmsearch_assembly/query_sequences"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/type",
                            "id": "#cmsearch-condition.cwl/cmsearch_assembly/type"
                        }
                    ],
                    "out": [
                        "#cmsearch-condition.cwl/cmsearch_assembly/concatenate_matches",
                        "#cmsearch-condition.cwl/cmsearch_assembly/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-condition.cwl/cmsearch_assembly"
                },
                {
                    "when": "$(inputs.type == 'raw')",
                    "label": "Search sequence(s) against a covariance model database for amplicon and wgs",
                    "run": "#cmsearch-multimodel-raw-data.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-condition.cwl/clan_info",
                            "id": "#cmsearch-condition.cwl/cmsearch_raw_data/clan_info"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/covariance_models",
                            "id": "#cmsearch-condition.cwl/cmsearch_raw_data/covariance_models"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/query_sequences",
                            "id": "#cmsearch-condition.cwl/cmsearch_raw_data/query_sequences"
                        },
                        {
                            "source": "#cmsearch-condition.cwl/type",
                            "id": "#cmsearch-condition.cwl/cmsearch_raw_data/type"
                        }
                    ],
                    "out": [
                        "#cmsearch-condition.cwl/cmsearch_raw_data/concatenate_matches",
                        "#cmsearch-condition.cwl/cmsearch_raw_data/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-condition.cwl/cmsearch_raw_data"
                }
            ],
            "id": "#cmsearch-condition.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/author": "Ekaterina Sakharova"
        },
        {
            "class": "Workflow",
            "label": "Identifies non-coding RNAs using Rfams covariance models",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#cmsearch-multimodel-raw-data.cwl/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#cmsearch-multimodel-raw-data.cwl/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-multimodel-raw-data.cwl/query_sequences"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/result",
                    "type": "File",
                    "id": "#cmsearch-multimodel-raw-data.cwl/concatenate_matches"
                },
                {
                    "outputSource": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/result",
                    "type": "File",
                    "id": "#cmsearch-multimodel-raw-data.cwl/deoverlapped_matches"
                }
            ],
            "steps": [
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/covariance_models",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cat_models/files"
                        },
                        {
                            "default": "models_cmsearch",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cat_models/outputFileName"
                        },
                        {
                            "default": ".all.tblout",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cat_models/postfix"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/cat_models/result"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/cat_models"
                },
                {
                    "label": "Search sequence(s) against a covariance model database",
                    "run": "#infernal-cmsearch-v1.1.2.cwl",
                    "scatter": "#cmsearch-multimodel-raw-data.cwl/cmsearch/query_sequences",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/cat_models/result",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/covariance_model_database"
                        },
                        {
                            "default": 8,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/cpu"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/cut_ga"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/only_hmm"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/split_fasta/chunks",
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/query_sequences"
                        },
                        {
                            "default": 1000,
                            "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch/search_space_size"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/cmsearch/matches"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/cmsearch"
                },
                {
                    "label": "Remove lower scoring overlaps from cmsearch --tblout files.",
                    "run": "#cmsearch-deoverlap-v0.02.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/clan_info",
                            "id": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/clan_information"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/cmsearch/matches",
                            "id": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/cmsearch_matches"
                        }
                    ],
                    "scatter": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/cmsearch_matches",
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/remove_overlaps/deoverlapped_matches",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/files"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/query_sequences",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/outputFileName"
                        },
                        {
                            "default": ".cmsearch.all.tblout.deoverlapped",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/postfix"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches/result"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_deoverlapped_matches"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/cmsearch/matches",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/files"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/query_sequences",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/outputFileName"
                        },
                        {
                            "default": ".cmsearch.all.tblout",
                            "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/postfix"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches/result"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/run_concatenate_matches"
                },
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 2000000,
                            "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta/chunk_size"
                        },
                        {
                            "default": "False",
                            "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta/number_of_output_files"
                        },
                        {
                            "default": "False",
                            "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta/same_number_of_residues"
                        },
                        {
                            "source": "#cmsearch-multimodel-raw-data.cwl/query_sequences",
                            "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta/seqs"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel-raw-data.cwl/split_fasta/chunks"
                    ],
                    "id": "#cmsearch-multimodel-raw-data.cwl/split_fasta"
                }
            ],
            "id": "#cmsearch-multimodel-raw-data.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2020",
            "http://schema.org/author": "Ekaterina Sakharova, Martin Beracochea",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "ramMin": 25000,
                    "ramMax": 25000,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#rna_prediction-sub-wf.cwl/input_sequences"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/ncRNA_ribosomal_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#rna_prediction-sub-wf.cwl/ncRNA_ribosomal_models"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/pattern_5.8S"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/pattern_5S"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/pattern_LSU"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/pattern_SSU"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/silva_lsu_database"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/silva_lsu_otus"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/silva_lsu_taxonomy"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".mscluster",
                            "required": null
                        }
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/silva_ssu_database"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/silva_ssu_otus"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/silva_ssu_taxonomy"
                },
                {
                    "type": "string",
                    "id": "#rna_prediction-sub-wf.cwl/type"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/counts",
                    "id": "#rna_prediction-sub-wf.cwl/LSU-SSU-count"
                },
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/LSU_seqs",
                    "id": "#rna_prediction-sub-wf.cwl/LSU_coords"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits/LSU_seqs",
                    "id": "#rna_prediction-sub-wf.cwl/LSU_fasta"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#rna_prediction-sub-wf.cwl/classify_LSUs/out_dir",
                    "id": "#rna_prediction-sub-wf.cwl/LSU_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/SSU_seqs",
                    "id": "#rna_prediction-sub-wf.cwl/SSU_coords"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#rna_prediction-sub-wf.cwl/extract_subunits/SSU_seqs",
                    "id": "#rna_prediction-sub-wf.cwl/SSU_fasta"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#rna_prediction-sub-wf.cwl/classify_SSUs/out_dir",
                    "id": "#rna_prediction-sub-wf.cwl/SSU_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/concatenate_matches",
                    "id": "#rna_prediction-sub-wf.cwl/cmsearch_result"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#rna_prediction-sub-wf.cwl/gzip_files/compressed_file",
                    "id": "#rna_prediction-sub-wf.cwl/compressed_rnas"
                },
                {
                    "type": "File",
                    "outputSource": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/deoverlapped_matches",
                    "id": "#rna_prediction-sub-wf.cwl/ncRNA"
                },
                {
                    "type": "int",
                    "outputSource": "#rna_prediction-sub-wf.cwl/classify_LSUs/number_lines_mapseq",
                    "id": "#rna_prediction-sub-wf.cwl/number_LSU_mapseq"
                },
                {
                    "type": "int",
                    "outputSource": "#rna_prediction-sub-wf.cwl/classify_SSUs/number_lines_mapseq",
                    "id": "#rna_prediction-sub-wf.cwl/number_SSU_mapseq"
                }
            ],
            "steps": [
                {
                    "when": "$(inputs.fasta_count > 0)",
                    "run": "#classify-otu-visualise.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/LSU_seqs",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/fasta"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/count_lsu_fasta/count",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/fasta_count"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/input_sequences",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/file_for_prefix"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_lsu_database",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/mapseq_ref"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_lsu_taxonomy",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/mapseq_taxonomy"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_LSU",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/otu_label"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_lsu_otus",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/otu_ref"
                        },
                        {
                            "default": "LSU",
                            "id": "#rna_prediction-sub-wf.cwl/classify_LSUs/return_dirname"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/classify_LSUs/out_dir",
                        "#rna_prediction-sub-wf.cwl/classify_LSUs/number_lines_mapseq"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/classify_LSUs"
                },
                {
                    "when": "$(inputs.fasta_count > 0)",
                    "run": "#classify-otu-visualise.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/SSU_seqs",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/fasta"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/count_ssu_fasta/count",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/fasta_count"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/input_sequences",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/file_for_prefix"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_ssu_database",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/mapseq_ref"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_ssu_taxonomy",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/mapseq_taxonomy"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_SSU",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/otu_label"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/silva_ssu_otus",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/otu_ref"
                        },
                        {
                            "default": "SSU",
                            "id": "#rna_prediction-sub-wf.cwl/classify_SSUs/return_dirname"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/classify_SSUs/out_dir",
                        "#rna_prediction-sub-wf.cwl/classify_SSUs/number_lines_mapseq"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/classify_SSUs"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#rna_prediction-sub-wf.cwl/count_lsu_fasta/number"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/LSU_seqs",
                            "id": "#rna_prediction-sub-wf.cwl/count_lsu_fasta/sequences"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/count_lsu_fasta/count"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/count_lsu_fasta"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#rna_prediction-sub-wf.cwl/count_ssu_fasta/number"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/SSU_seqs",
                            "id": "#rna_prediction-sub-wf.cwl/count_ssu_fasta/sequences"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/count_ssu_fasta/count"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/count_ssu_fasta"
                },
                {
                    "run": "#extract-coords_awk.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/deoverlapped_matches",
                            "id": "#rna_prediction-sub-wf.cwl/extract_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/extract_coords/matched_seqs_with_coords"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/extract_coords"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/index_reads/sequences_with_index",
                            "id": "#rna_prediction-sub-wf.cwl/extract_sequences/indexed_sequences"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_coords/matched_seqs_with_coords",
                            "id": "#rna_prediction-sub-wf.cwl/extract_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/extract_sequences/sequences"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/extract_sequences"
                },
                {
                    "run": "#get_subunits.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_sequences/sequences",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/input"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_5.8S",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/pattern_5.8S"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_5S",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/pattern_5S"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_LSU",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/pattern_LSU"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_SSU",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits/pattern_SSU"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/extract_subunits/SSU_seqs",
                        "#rna_prediction-sub-wf.cwl/extract_subunits/LSU_seqs",
                        "#rna_prediction-sub-wf.cwl/extract_subunits/fastas"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/extract_subunits"
                },
                {
                    "run": "#get_subunits_coords.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_coords/matched_seqs_with_coords",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/input"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_LSU",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/pattern_LSU"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/pattern_SSU",
                            "id": "#rna_prediction-sub-wf.cwl/extract_subunits_coords/pattern_SSU"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/extract_subunits_coords/SSU_seqs",
                        "#rna_prediction-sub-wf.cwl/extract_subunits_coords/LSU_seqs",
                        "#rna_prediction-sub-wf.cwl/extract_subunits_coords/counts"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/extract_subunits_coords"
                },
                {
                    "run": "#cmsearch-condition.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/ncRNA_ribosomal_model_clans",
                            "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/clan_info"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/ncRNA_ribosomal_models",
                            "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/covariance_models"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/input_sequences",
                            "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/query_sequences"
                        },
                        {
                            "source": "#rna_prediction-sub-wf.cwl/type",
                            "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/type"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/concatenate_matches",
                        "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs/deoverlapped_matches"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/find_ribosomal_ncRNAs"
                },
                {
                    "run": "#gzip.cwl",
                    "scatter": "#rna_prediction-sub-wf.cwl/gzip_files/uncompressed_file",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/extract_subunits/fastas",
                            "id": "#rna_prediction-sub-wf.cwl/gzip_files/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/gzip_files/compressed_file"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/gzip_files"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#rna_prediction-sub-wf.cwl/input_sequences",
                            "id": "#rna_prediction-sub-wf.cwl/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#rna_prediction-sub-wf.cwl/index_reads/sequences_with_index"
                    ],
                    "id": "#rna_prediction-sub-wf.cwl/index_reads"
                }
            ],
            "id": "#rna_prediction-sub-wf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#seqprep-subwf.cwl/forward_reads"
                },
                {
                    "type": "int",
                    "id": "#seqprep-subwf.cwl/paired_reads_length_filter"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#seqprep-subwf.cwl/reverse_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#seqprep-subwf.cwl/single_reads"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputSource": [
                        "#seqprep-subwf.cwl/count_submitted_reads/count",
                        "#seqprep-subwf.cwl/count_submitted_reads_single/count"
                    ],
                    "pickValue": "first_non_null",
                    "id": "#seqprep-subwf.cwl/count_forward_submitted_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#seqprep-subwf.cwl/filter_paired/json_report",
                    "id": "#seqprep-subwf.cwl/fastp_report"
                },
                {
                    "type": "File",
                    "outputSource": [
                        "#seqprep-subwf.cwl/unzip_merged_reads/unzipped_file",
                        "#seqprep-subwf.cwl/unzip_single_reads/unzipped_file"
                    ],
                    "pickValue": "first_non_null",
                    "id": "#seqprep-subwf.cwl/unzipped_single_reads"
                }
            ],
            "steps": [
                {
                    "run": "#count_lines.cwl",
                    "when": "$(inputs.single == undefined)",
                    "in": [
                        {
                            "default": 4,
                            "id": "#seqprep-subwf.cwl/count_submitted_reads/number"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/forward_reads",
                            "id": "#seqprep-subwf.cwl/count_submitted_reads/sequences"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/count_submitted_reads/single"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/count_submitted_reads/count"
                    ],
                    "id": "#seqprep-subwf.cwl/count_submitted_reads"
                },
                {
                    "run": "#count_lines.cwl",
                    "when": "$(inputs.target_reads != undefined)",
                    "in": [
                        {
                            "default": 4,
                            "id": "#seqprep-subwf.cwl/count_submitted_reads_single/number"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/unzip_single_reads/unzipped_file",
                            "id": "#seqprep-subwf.cwl/count_submitted_reads_single/sequences"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/count_submitted_reads_single/target_reads"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/count_submitted_reads_single/count"
                    ],
                    "id": "#seqprep-subwf.cwl/count_submitted_reads_single"
                },
                {
                    "run": "#fastp.cwl",
                    "when": "$(inputs.single == undefined)",
                    "in": [
                        {
                            "default": false,
                            "id": "#seqprep-subwf.cwl/filter_paired/base_correction"
                        },
                        {
                            "default": false,
                            "id": "#seqprep-subwf.cwl/filter_paired/disable_trim_poly_g"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/forward_reads",
                            "id": "#seqprep-subwf.cwl/filter_paired/fastq1"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/reverse_reads",
                            "id": "#seqprep-subwf.cwl/filter_paired/fastq2"
                        },
                        {
                            "default": false,
                            "id": "#seqprep-subwf.cwl/filter_paired/force_polyg_tail_trimming"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/paired_reads_length_filter",
                            "id": "#seqprep-subwf.cwl/filter_paired/min_length_required"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/filter_paired/single"
                        },
                        {
                            "default": 8,
                            "id": "#seqprep-subwf.cwl/filter_paired/threads"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/filter_paired/out_fastq1",
                        "#seqprep-subwf.cwl/filter_paired/out_fastq2",
                        "#seqprep-subwf.cwl/filter_paired/json_report"
                    ],
                    "id": "#seqprep-subwf.cwl/filter_paired"
                },
                {
                    "label": "Paired-end overlapping reads are merged",
                    "run": "#seqprep.cwl",
                    "when": "$(inputs.single == undefined)",
                    "in": [
                        {
                            "source": "#seqprep-subwf.cwl/filter_paired/out_fastq1",
                            "id": "#seqprep-subwf.cwl/overlap_reads/forward_reads"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/forward_reads",
                            "id": "#seqprep-subwf.cwl/overlap_reads/namefile"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/filter_paired/out_fastq2",
                            "id": "#seqprep-subwf.cwl/overlap_reads/reverse_reads"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/overlap_reads/single"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/overlap_reads/merged_reads",
                        "#seqprep-subwf.cwl/overlap_reads/forward_unmerged_reads",
                        "#seqprep-subwf.cwl/overlap_reads/reverse_unmerged_reads"
                    ],
                    "id": "#seqprep-subwf.cwl/overlap_reads"
                },
                {
                    "when": "$(inputs.target_reads != undefined)",
                    "run": "#multiple-gunzip.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#seqprep-subwf.cwl/unzip_merged_reads/reads"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/overlap_reads/merged_reads",
                            "id": "#seqprep-subwf.cwl/unzip_merged_reads/target_reads"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/unzip_merged_reads/unzipped_file"
                    ],
                    "id": "#seqprep-subwf.cwl/unzip_merged_reads"
                },
                {
                    "run": "#multiple-gunzip.cwl",
                    "when": "$(inputs.target_reads != undefined)",
                    "in": [
                        {
                            "default": true,
                            "id": "#seqprep-subwf.cwl/unzip_single_reads/reads"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/unzip_single_reads/target_reads"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/unzip_single_reads/unzipped_file"
                    ],
                    "id": "#seqprep-subwf.cwl/unzip_single_reads"
                }
            ],
            "id": "#seqprep-subwf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.2",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "http://edamontology.org/EDAM_1.20.owl",
        "https://schema.org/version/latest/schemaorg-current-http.rdf",
        "http://edamontology.org/EDAM_1.18.owl",
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
